/**************************************************************/
/** Gestisce statistiche TRIMES SU Facebook PAGE LEVEL DATA  **/
/** Author: @mauroferri Data: 27/3/2018                      **/
/**************************************************************/

TITLE1 'COMUNE DI RIMINI - UFFICIO COMUNICAZIONE';

%let trimestre=GENNAIO 2018;
%let path=/folders/myfolders/sasuser.v94/facebook/;
%let eticpaesi=etichette-paesi.txt;             /* Tabelle 18 - 22 - 28 */
%let eticcitta=etichette-citta.txt;             /* Tabelle 31 */
%let varcitta=variabilicitta.txt;               /* Tabelle 31 */
%let eticdomini=etichette-domini.txt;           /* Tabelle 38 */
%let vardomini=variabilidomini.txt;
TITLE2 "Facebook Insights &trimestre PAGE LEVEL";
FOOTNOTE2 'Elaborazione della Redazione web';
OPTIONS linesize=116 PAGESIZE=62 NONUMBER NODATE CENTER NOSOURCE;
LIBNAME facebook "/folders/myfolders/sasuser.v94/facebook";
%let page=/folders/myfolders/sasuser.v94/facebook/Facebook Insights Data Export - Comune di Rimini - FEB18.xlsx;
filename percorso "&path";
RUN;

/******************/
/* 00 KEY METRICS */
/******************/
TITLE3 "#0 KEY METRICS";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.key_metrics_page_00
		    DBMS=XLSX
		    REPLACE;
		    DATAROW=3;
SHEET="Key Metrics";
RUN;

DATA TEMP(RENAME=(Nuovi__Mi_piace__al_giorno=mi_piace) rename=(Non_mi_piace_pi___al_giorno=nonmipiace) 
rename=(Utenti_coinvolti_sulla_Pagina_al=utenticoinvolti) rename=(Copertura_totale_al_giorno=copertura)
rename=(Consumatori_totali_al_giorno=consumatori) rename=(Utilizzi_della_Pagina_al_giorno=utilizzi)
rename=(Registrazioni_totali_al_giorno=registrazioni) rename=(Numero_di_clic_sul_sito_Web_in_t=clicksitoweb)
);
mese=month(Data);
SET facebook.key_metrics_page_00;
RUN;
proc sort data=TEMP;
by mese;
Run;

PROC TABULATE data=TEMP format=comma10.;
CLASS Data;
VAR mi_piace nonmipiace utenticoinvolti copertura consumatori utilizzi registrazioni clicksitoweb;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL  mi_piace="Nuovi Mi Piace" nonmipiace="Non mi piace" utenticoinvolti="Utenti Coinvolti" copertura="Copertura" consumatori="Consumatori" utilizzi="Utilizzi" registrazioni="Registrazioni" clicksitoweb="Click sul sito"; 
      TABLE Data all,mi_piace*f=comma10. nonmipiace*f=comma10. utenticoinvolti*f=comma10. copertura*f=comma10. consumatori*f=comma10. registrazioni*f=comma10. utilizzi*f=comma10. clicksitoweb*f=comma10./ BOX="0 Key Metrics";
RUN;



/************************/
/* 01 DAILY LIKE SOURCE */
/************************/

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_like_source_01
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Like Source";
RUN;

TITLE3 "#1 Al giorno: il numero di persone che hanno messo Mi piace alla tua Pagina, suddiviso per i punti più comuni da cui si può compiere questa azione. (Utenti unici)";
RUN;

proc TABULATE data=facebook.daily_like_source_01 ;
CLASS Data;
VAR page_profile feed_story search hovercard mobile ads banhammer feed_chaining feed_story page_invite page_invite_escape_hatch 
    page_timeline pages_liked_feed photo_snowlift;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL page_profile="PageProfile" feed_story="FeedStory" search="Search" hovercard="Hovercard" mobile="Mobile" ads="Ads"
      banhammer="BanHammer" feed_chaining="FeedChaining" page_invite="PageInvite" page_invite_escape_hatch="PageInviteEsc" 
      page_timeline="PageTimeline" pages_liked_feed="PageLikedFeed" photo_snowlift="PhotoSnowlift"; 
      TABLE
      Data ALL, page_profile*f=comma10.  feed_story*f=comma10. search*f=comma10. hovercard*f=comma10. mobile*f=comma10.
                ads*f=comma10. banhammer*f=comma10. feed_chaining*f=comma10. page_invite*f=comma10. page_invite_escape_hatch*f=comma10.
                page_timeline*f=comma10. pages_liked_feed*f=comma10. photo_snowlift*f=comma10. 
       / BOX="1 Daily Like Sources";
RUN;

/*************************************************************/
/* 02 NUMERO DI PERSONE CHE LA PAGINA HA RAGGIUNTO AL GIORNO */
/*************************************************************/
TITLE3 "#2 Al giorno: il numero di persone che la tua Pagina ha raggiunto, suddiviso per il numero di volte in cui tali persone hanno visualizzato un contenuto qualsiasi relativo alla tua Pagina. (Utenti unici)"; 
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_total_freq_02
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Total frequency distri...";
RUN;

proc TABULATE data=facebook.daily_total_freq_02 ;
CLASS Data;
VAR _1 _2 _3 _4 _5 _6_10 _11_20 _21_;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL _1="1 vis." _2="2 vis." _3="3 vis." _4="4 vis." _5="5 vis." _6_10="da 6 a 10 vis." _11_20="da 11 a 20 vis." _21_="oltre 21"; 
      TABLE
      Data all, _1*f=comma10. _2*f=comma10. _3*f=comma10. _4*f=comma10. _5*f=comma10. _6_10*f=comma10. _11_20*f=comma10. _21_*f=comma10. / BOX="2 Daily Total Frequency - Numero di persone che la pagina ha raggiunto";
RUN;



/*************************************************************/
/* 05 NUMERO DI PERSONE CHE HANNO VISTO I POST AL GIORNO     */
/*************************************************************/

TITLE3 "#5  Al giorno: il numero di persone che hanno visto i post della tua Pagina, suddiviso per il numero di volte in cui le persone hanno visto i tuoi post. (Utenti unici)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_page_posts_freq_05
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Page posts frequency d...";
RUN;

proc TABULATE data=facebook.daily_page_posts_freq_05 ;
CLASS Data;
VAR _1 _2 _3 _4 _5 _6_10 _11_20 _21_;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL _1="1 vis." _2="2 vis." _3="3 vis." _4="4 vis." _5="5 vis." _6_10="da 6 a 10 vis." _11_20="da 11 a 20 vis." _21_="oltre 21"; 
      TABLE
      Data all, _1*f=comma10. _2*f=comma10. _3*f=comma10. _4*f=comma10. _5*f=comma10. _6_10*f=comma10. _11_20*f=comma10. _21_*f=comma10. / BOX="5 Daily Page posts frequency";
RUN;



/********************************************************************************/
/* 08 NUMERO DI PERSONE CHE PARLANO DELLA PAGINA PER TIPO DI NOTIZIA AL GIORNO  */
/********************************************************************************/

TITLE3 "#8 Al giorno: il numero di persone che parlano della tua Pagina suddivise per tipo di notizia. (Utenti unici)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_talking_about_08
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Talking About This by...";
RUN;


proc TABULATE data=facebook.daily_talking_about_08 ;
CLASS Data;
VAR checkin
	coupon
	event
	fan
	mention
	other
	page_post
	question
	user_post;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL checkin="Check in" coupon="Coupon" event="Evento" fan="Fan" mention="Mention o Tag" other="Altro" page_post="Page Post" question="Domanda" user_post="Post utente"; 
      TABLE
      Data all, checkin*f=comma10. coupon*f=comma10. event*f=comma10. fan*f=comma10. mention*f=comma10. other*f=comma10. page_post*f=comma10. question*f=comma10. user_post*f=comma10./ BOX="8 Daily Talking About - al giorno";
RUN;



/*****************************************************************************/
/* 11 NUMERO DI NOTIZIE RELATIVE PAGINA PER TIPO DI NOTIZIA AL GIORNO        */
/*****************************************************************************/
TITLE3 "#11 Al giorno: il numero di notizie relative alla tua Pagina per tipo di notizia. (Numero totale)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_page_stories_11
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Page Stories By Story...";
RUN;

proc TABULATE data=facebook.daily_page_stories_11 ;
CLASS Data;
VAR checkin
	coupon
	event
	fan
	mention
	other
	page_post
	question
	user_post;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL checkin="Check in" coupon="Coupon" event="Evento" fan="Fan" mention="Mention o Tag" other="Altro" page_post="Page Post" question="Domanda" user_post="Post utente"; 
      TABLE
      Data all, checkinf=comma10. coupon*f=comma10. event*f=comma10. fan*f=comma10. mention*f=comma10. 
      other*f=comma10. page_post*f=comma10. question*f=comma10. user_post*f=comma10.
      / BOX="11 Daily Page Stories By Story";
RUN;



/*****************************************************************************/
/* 14 NUMERO DI CLIC SU UNO DEI CONTENUTI PER TIPO AL GIORNO                 */
/*****************************************************************************/
/* Non sono incluse le notizie create senza cliccare sul contenuto della Pagina (ad es. mettendo "Mi piace" a una Pagina dal diario) */
TITLE3 "#14 Numero di clic su uno dei contenuti della pagina per tipo al giorno (Numero totale)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_page_consuptions_14
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Page consumptions by type";
RUN;


proc TABULATE data=facebook.daily_page_consuptions_14 ;
CLASS Data;
VAR button_clicks
	link_clicks
	other_clicks
	photo_view
	video_play
;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
      TABLE
      Data all, button_clicks*f=comma10. link_clicks*f=comma10. other_clicks*f=comma10. photo_view*f=comma10. video_play*f=comma10. 
      / BOX="14 Daily Page consumptions by type";
RUN;





/***************************************************************************/
/* 17 TOTALE: DATI DEMOGRAFICI AGGREGATI RELATIVI ALLE PERSONE             */
/***************************************************************************/
TITLE3 "#17 Totale: dati demografici aggregati relativi alle persone a cui piace la tua Pagina in base alle informazioni su età e genere specificate nel loro profilo. (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.lifetime_likes_gender_17
		    DBMS=XLSX
		    REPLACE;
SHEET="Lifetime Likes by Gender and...";
RUN;

PROC MEANS data=facebook.lifetime_likes_gender_17;
VAR F_13_17
	F_18_24
	F_25_34
	F_35_44
	F_45_54
	F_55_64
	F_65_
	M_13_17
	M_18_24
	M_25_34
	M_35_44
	M_45_54
	M_55_64
	M_65_
	U_13_17
	U_18_24
	U_25_34
	U_35_44
	U_45_54
	U_55_64
	U_65_;
RUN;

proc TABULATE data=facebook.lifetime_likes_gender_17 ;
CLASS Data;
VAR F_13_17 F_18_24 F_25_34 F_35_44 F_45_54 F_55_64 F_65_ M_13_17 M_18_24 M_25_34 M_35_44 M_45_54 M_55_64 M_65_
	U_13_17 U_18_24 U_25_34 U_35_44 U_45_54 U_55_64 U_65_;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL F_13_17="F 13-17" F_18_24="F 18-24" F_25_34="F 25-34" F_35_44="F 35-44" F_45_54="F 45-54" F_55_64="F 55-64" F_65_="F 65+"
      M_13_17="M 13-17" M_18_24="M 18-24" M_25_34="M 25-34" M_35_44="M 35-44" M_45_54="M 45-54" M_55_64="M 55-64" M_65_="M 65+"
      U_13_17="U 13-17" U_18_24="U 18-24" U_25_34="U 25-34" U_35_44="U 35-44" U_45_54="U 45-54" U_55_64="U 55-64" U_65_="U 65+"; 
      TABLE
      Data all, F_13_17*f=comma10. F_18_24*f=comma10. F_25_34*f=comma10. F_35_44*f=comma10. F_45_54*f=comma10. F_55_64*f=comma10. F_65_*f=comma10. 
      			M_13_17*f=comma10. M_18_24*f=comma10. M_25_34*f=comma10. M_35_44*f=comma10. M_45_54*f=comma10. M_55_64*f=comma10. M_65_*f=comma10.
				U_13_17*f=comma10. U_18_24*f=comma10. U_25_34*f=comma10. U_35_44*f=comma10. U_45_54*f=comma10. U_55_64*f=comma10. U_65_*f=comma10.
      / BOX="17 Lifetime Likes by Gender and Age";
RUN;



/*********************************************************************************/
/* 18 TOTALE: DATI AGGREGATI DI FACEBOOK SULLA POSIZIONE DELLE PERSONE PER PAESE */
/*********************************************************************************/
TITLE "#18 Totale: dati aggregati di Facebook sulla posizione, ordinati per Paese, sulle persone a cui piace la tua Pagina. (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.lifetime_likes_country_18
		    DBMS=XLSX
		    REPLACE;
SHEET="Lifetime Likes By Country";
RUN;


proc TABULATE data=facebook.lifetime_likes_country_18 format=comma10.;
  CLASS Data;
  VAR AR AT AU BD BE BG BR CA CH CL CN CO CZ DE DZ EC EG ES FR GB GE GR HU ID IE IN IQ IT JP MA MD MK MT MX NL NO PE PH PK PL PT RO RS RU SE SM TH TN TR UA US;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
LABEL  
%inc percorso(etichette-paesi.txt);
 ;
FORMAT Data DDMMYY10.;
      TABLE
      Data all, AR AT AU BD BE BG BR CA CH CL CN CO CZ DE DZ EC EG ES FR GB GE GR HU ID IE IN IQ IT JP MA MD MK MT MX NL NO PE PH PK PL PT RO RS RU SE SM TH TN TR UA US  
      / BOX="18 Lifetime Likes By Country";
RUN;

/***************************************************************************************/
/* 19 TOTALE: DATI AGGREGATI DI FACEBOOK SULLA POSIZIONE GEOGRAFICA ORDINATI PER CITTA'*/
/***************************************************************************************/
TITLE3 "#19 Totale: dati aggregati di Facebook sulla posizione geografica, ordinati per città, riguardanti le persone a cui piace la tua Pagina. (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.lifetime_likes_city_19
		    DBMS=XLSX
		    REPLACE;
SHEET="Lifetime Likes by City";
RUN;
/*
Proc means data=facebook.lifetime_likes_city_19;
Run;
*/
proc TABULATE data=facebook.lifetime_likes_city_19 format=comma10. ;
CLASS Data;
VAR 
Ancona__Marche Bari__Puglia VAR5 Bologna__Emilia_Romagna Borgo_Maggiore__Emilia_Romagna Brescia__Lombardia Cattolica__Emilia_Romagna
Cervia__Emilia_Romagna Cesena__Emilia_Romagna Cesenatico__Emilia_Romagna VAR13 Coriano__Emilia_Romagna Domagnano__Emilia_Romagna
Faenza__Emilia_Romagna Fano__Marche Ferrara__Emilia_Romagna Firenze__Toscana VAR20 VAR21 Genova__Liguria Londra__Inghilterra__Regno_Unito
Milano__Lombardia Misano_Adriatico__Emilia_Romagna Modena__Emilia_Romagna Montescudo__Emilia_Romagna Morciano_di_Romagna__Emilia_Roma
Napoli__Campania Novafeltria__Emilia_Romagna Padova__Veneto Palermo Parma__Emilia_Romagna Pesaro__Marche Pesaro_e_Urbino__Marche
Poggio_Berni__Emilia_Romagna Ravenna__Emilia_Romagna VAR38 Riccione__Emilia_Romagna Rimini__Emilia_Romagna Roma__Lazio
San_Clemente__Emilia_Romagna San_Giovanni_in_Marignano__Emili San_Mauro_Pascoli__Emilia_Romagn Santarcangelo__Emilia_Romagna Santarcangelo_di_Romagna__Emilia
Savignano_sul_Rubicone__Emilia_R VAR48 Tirana__Prefettura_di_Tirana__Al Torino__Piemonte Venezia__Veneto Vergiano__Emilia_Romagna
Verona__Veneto Verucchio__Emilia_Romagna Villa_Verucchio__Emilia_Romagna Viserba__Emilia_Romagna
;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
LABEL Ancona__Marche="Ancona" Bari__Puglia="Bari" VAR5="NN" Bologna__Emilia_Romagna="Bologna" Borgo_Maggiore__Emilia_Romagna="Borgo Maggiore" Brescia__Lombardia="Brescia" Cattolica__Emilia_Romagna="Cattolica"
Cervia__Emilia_Romagna="Cervia" Cesena__Emilia_Romagna="Cesena" Cesenatico__Emilia_Romagna="Cesenatico" VAR13="NN" Coriano__Emilia_Romagna="Coriano" Domagnano__Emilia_Romagna="Domagnano"
Faenza__Emilia_Romagna="Faenza" Fano__Marche="Fano" Ferrara__Emilia_Romagna="Ferrara" Firenze__Toscana="Firenze" VAR20="NN" VAR21="NN" Genova__Liguria="Genova" Londra__Inghilterra__Regno_Unito="Londra"
Milano__Lombardia="Milano" Misano_Adriatico__Emilia_Romagna="Misano A." Modena__Emilia_Romagna="Modena" Montescudo__Emilia_Romagna="Montescudo" Morciano_di_Romagna__Emilia_Roma="Morciano"
Napoli__Campania="Napoli" Novafeltria__Emilia_Romagna="Novafeltria" Padova__Veneto="Padova" Palermo="Palermo" Parma__Emilia_Romagna="Parma" Pesaro__Marche Pesaro_e_Urbino__Marche="Pesaro"
Poggio_Berni__Emilia_Romagna="Poggio Berni" Ravenna__Emilia_Romagna="Ravenna" VAR38="NN" Riccione__Emilia_Romagna="Riccione" Rimini__Emilia_Romagna="Rimini" Roma__Lazio="Roma"
San_Clemente__Emilia_Romagna="San Clemente" San_Giovanni_in_Marignano__Emili="San Giovanni in M." San_Mauro_Pascoli__Emilia_Romagn="San Mauro Pascoli" Santarcangelo__Emilia_Romagna="Santarcangelo R." Santarcangelo_di_Romagna__Emilia="Santarcangelo di R."
Savignano_sul_Rubicone__Emilia_R="Savignano sul R." VAR48="NN" Tirana__Prefettura_di_Tirana__Al="Tirana" Torino__Piemonte="Torinio" Venezia__Veneto="Venezia" Vergiano__Emilia_Romagna="Vergiano"
Verona__Veneto="Verona" Verucchio__Emilia_Romagna="Veruccio" Villa_Verucchio__Emilia_Romagna="Villa Verucchio" Viserba__Emilia_Romagna="Viserba";
FORMAT Data DDMMYY10.;
      TABLE
      Data all, Ancona__Marche Bari__Puglia VAR5 Bologna__Emilia_Romagna Borgo_Maggiore__Emilia_Romagna Brescia__Lombardia Cattolica__Emilia_Romagna
Cervia__Emilia_Romagna Cesena__Emilia_Romagna Cesenatico__Emilia_Romagna VAR13 Coriano__Emilia_Romagna Domagnano__Emilia_Romagna
Faenza__Emilia_Romagna Fano__Marche Ferrara__Emilia_Romagna Firenze__Toscana VAR20 VAR21 Genova__Liguria Londra__Inghilterra__Regno_Unito
Milano__Lombardia Misano_Adriatico__Emilia_Romagna Modena__Emilia_Romagna Montescudo__Emilia_Romagna Morciano_di_Romagna__Emilia_Roma
Napoli__Campania Novafeltria__Emilia_Romagna Padova__Veneto Palermo Parma__Emilia_Romagna Pesaro__Marche Pesaro_e_Urbino__Marche
Poggio_Berni__Emilia_Romagna Ravenna__Emilia_Romagna VAR38 Riccione__Emilia_Romagna Rimini__Emilia_Romagna Roma__Lazio
San_Clemente__Emilia_Romagna San_Giovanni_in_Marignano__Emili San_Mauro_Pascoli__Emilia_Romagn Santarcangelo__Emilia_Romagna Santarcangelo_di_Romagna__Emilia
Savignano_sul_Rubicone__Emilia_R VAR48 Tirana__Prefettura_di_Tirana__Al Torino__Piemonte Venezia__Veneto Vergiano__Emilia_Romagna
Verona__Veneto Verucchio__Emilia_Romagna Villa_Verucchio__Emilia_Romagna Viserba__Emilia_Romagna
      / BOX="19 Lifetime Likes by City";
RUN;

/****************************************************************************************/
/* 20 TOTALE: DATI AGGREGATI SULLA LINGUA RELATIVE ALLE PERSONE CUI PIACE LA TUA PAGINA */
/****************************************************************************************/
TITLE3 "#20 Totale: dati aggregati sulla lingua relativi alle persone a cui piace la tua Pagina in base alla lingua impostata al momento dell'accesso a Facebook. (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.lifetime_likes_language_20
		    DBMS=XLSX
		    REPLACE;
SHEET="Lifetime Likes by Language";
RUN;

proc TABULATE data=facebook.lifetime_likes_language_20 format=comma10. ;
CLASS Data;
VAR 
ar_AR
az_AZ
bg_BG
bn_IN
ca_ES
cs_CZ
da_DK
de_DE
el_GR
en_GB
en_PI
en_US
es_ES
es_LA
fa_IR
fi_FI
fr_CA
fr_FR
he_IL
hr_HR
hu_HU
id_ID
it_IT
ja_JP
ka_GE
ko_KR
lt_LT
mk_MK
ms_MY
nb_NO
nl_NL
pl_PL
pt_BR
pt_PT
ro_RO
ru_RU
sk_SK
sl_SI
sq_AL
sr_RS
sv_SE
th_TH
tr_TR
uk_UA
zh_CN
zh_TW;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
      TABLE
Data all, ar_AR
az_AZ
bg_BG
bn_IN
ca_ES
cs_CZ
da_DK
de_DE
el_GR
en_GB
en_PI
en_US
es_ES
es_LA
fa_IR
fi_FI
fr_CA
fr_FR
he_IL
hr_HR
hu_HU
id_ID
it_IT
ja_JP
ka_GE
ko_KR
lt_LT
mk_MK
ms_MY
nb_NO
nl_NL
pl_PL
pt_BR
pt_PT
ro_RO
ru_RU
sk_SK
sl_SI
sq_AL
sr_RS
sv_SE
th_TH
tr_TR
uk_UA
zh_CN
zh_TW
      / BOX="20 Lifetime Likes by Language";
RUN;


/**********************************************************************/
/* 25 NUMERO DI PERSONE CHE PARLANO DELLA PAGINA PER UTENTE AL GIORNO */
/**********************************************************************/
TITLE3 "#25 Al giorno: il numero di persone che parlano della Pagina per età e genere (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_demographic_people_25
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Demographics People Ta...";
RUN;
/* proc means data=facebook.daily_demographic_people_25; Run; */

proc TABULATE data=facebook.daily_demographic_people_25 ;
CLASS Data;
VAR F_13_17 F_18_24 F_25_34 F_35_44 F_45_54 F_55_64 F_65_ M_13_17 M_18_24 M_25_34 M_35_44 M_45_54 M_55_64 M_65_
	U_13_17 U_18_24 U_25_34 U_35_44 U_45_54 U_55_64 U_65_;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL F_13_17="F 13-17" F_18_24="F 18-24" F_25_34="F 25-34" F_35_44="F 35-44" F_45_54="F 45-54" F_55_64="F 55-64" F_65_="F 65+"
      M_13_17="M 13-17" M_18_24="M 18-24" M_25_34="M 25-34" M_35_44="M 35-44" M_45_54="M 45-54" M_55_64="M 55-64" M_65_="M 65+"
      U_13_17="U 13-17" U_18_24="U 18-24" U_25_34="U 25-34" U_35_44="U 35-44" U_45_54="U 45-54" U_55_64="U 55-64" U_65_="U 65+"; 
      TABLE
      Data all, F_13_17*f=comma10. F_18_24*f=comma10. F_25_34*f=comma10. F_35_44*f=comma10. F_45_54*f=comma10. F_55_64*f=comma10. F_65_*f=comma10. 
      			M_13_17*f=comma10. M_18_24*f=comma10. M_25_34*f=comma10. M_35_44*f=comma10. M_45_54*f=comma10. M_55_64*f=comma10. M_65_*f=comma10.
				U_13_17*f=comma10. U_18_24*f=comma10. U_25_34*f=comma10. U_35_44*f=comma10. U_45_54*f=comma10. U_55_64*f=comma10. U_65_*f=comma10.
      / BOX="25 Daily Demographics People Talking";
RUN;

/*********************************************************************/
/* 28 NUMERO DI PERSONE CHE PARLANO DELLA PAGINA PER PAESE AL GIORNO */
/*********************************************************************/
TITLE3 "#28 Al giorno: il numero di persone che parlano della Pagina suddivise per Paese (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_country_people_talk_28
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Country People Talking...";
RUN;

proc TABULATE data=facebook.daily_country_people_talk_28 format=comma10.;
  CLASS Data;
  VAR 
AF
AL
AR
AT
AU
AZ
BA
BB
BD
BE
BF
BG
BJ
BO
BR
BY
CA
CH
CI
CL
CM
CN
CO
CR
CU
CV
CZ
DE
DK
DO
DZ
EC
EE
EG
ES
FI
FR
GB
GE
GH
GN
GR
GT
HK
HR
HU
ID
IE
IL
IN
IQ
IR
IS
IT
JO
JP
KE
KH
LB
LK
LR
LT
LU
LV
LY
MA
MC
MD
ME
MK
MM
MN
MT
MU
MV
MX
MY
NG
NL
NO
NP
NZ
OM
PA
PE
PH
PK
PL
PR
PT
PY
QA
RO
RS
RU
SA
SE
SG
SI
SK
SM
SN
SV
SY
TH
TN
TR
TW
UA
US
UY
VE
VN
XK
ZA
ZM;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
LABEL  
%inc percorso(etichette-paesi.txt);
 ;
FORMAT Data DDMMYY10.;
      TABLE
Data all, 
AF
AL
AR
AT
AU
AZ
BA
BB
BD
BE
BF
BG
BJ
BO
BR
BY
CA
CH
CI
CL
CM
CN
CO
CR
CU
CV
CZ
DE
DK
DO
DZ
EC
EE
EG
ES
FI
FR
GB
GE
GH
GN
GR
GT
HK
HR
HU
ID
IE
IL
IN
IQ
IR
IS
IT
JO
JP
KE
KH
LB
LK
LR
LT
LU
LV
LY
MA
MC
MD
ME
MK
MM
MN
MT
MU
MV
MX
MY
NG
NL
NO
NP
NZ
OM
PA
PE
PH
PK
PL
PR
PT
PY
QA
RO
RS
RU
SA
SE
SG
SI
SK
SM
SN
SV
SY
TH
TN
TR
TW
UA
US
UY
VE
VN
XK
ZA
ZM
/ BOX="28 Daily Country People Talking";
RUN;


/**************************************************************************/
/* 31 NUMERO DI PERSONE CHE PARLANO DELLA PAGINA PER CITTA'               */
/**************************************************************************/
TITLE3 "#31 Al giorno: il numero di persone che parlano della Pagina suddivise per città. (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_city_people_talk_31
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily City People Talking Ab...";
RUN;
/* proc means data=facebook.daily_city_people_talk_31; Run; */

proc TABULATE data=facebook.daily_city_people_talk_31 format=comma10. ;
CLASS Data;
VAR 
%inc percorso("variabilicitta.txt");
;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
LABEL 
%inc percorso("etichette-citta.txt");
;
FORMAT Data DDMMYY10.;
      TABLE
Data all, 
VAR3
VAR4
Abbiategrasso__Lombardia
Abidjan__Regione_delle_Lagune__C
Abomey_Calavi__Dipartimento_dell
Accra__Regione_della_Grande_Accr
Acqui_Terme__Piemonte
Adelaide__Australia_Meridionale_
Adria__Veneto
Agnadello__Lombardia
Agrate_Conturbia__Piemonte
Agrigento
Agua_Prieta__Sonora
Aiello_del_Sabato__Campania
VAR17
Alba_Adriatica__Abruzzo
VAR19
Albignasego__Veneto
VAR21
Alcamo
Alessandria__Piemonte
Alessano__Puglia
VAR25
Alfero__Emilia_Romagna
Alfonsine__Emilia_Romagna
Altavilla_Irpina__Campania
Altedo__Emilia_Romagna
Amsterdam__Olanda_Settentrionale
Ancona__Marche
Andria__Puglia
Anversa__Belgio
Anzio__Lazio
Apice__Campania
Aquisgrana__Germania
VAR37
Arcevia__Marche
Arenillas__El_Oro_Province
Arezzo__Toscana
Ariano_Irpino__Campania
Ascea__Campania
Assisi__Umbria
Asti__Piemonte
VAR45
VAR46
Atri__Abruzzo
Atton__Francia
Aubevoye__Haute_Normandie
VAR50
Avellino__Campania
Aversa__Campania
Avezzano__Abruzzo
VAR54
Azzano__Veneto
Badia_Polesine__Veneto
Badia_Tedalda__Toscana
Bagnacavallo__Emilia_Romagna
Bagni_di_Lucca__Toscana
Bagno_di_Romagna__Emilia_Romagna
Bagnolo_Mella__Lombardia
Bagnoregio__Lazio
Baku__Azerbaigian
Barberino_di_Mugello__Toscana
Barcellona__Catalogna__Spagna
Bari__Puglia
Barile__Basilicata
Barletta__Puglia
Bassano_del_Grappa__Veneto
VAR70
VAR71
VAR72
Bellinzona__Canton_Ticino__Svizz
Belo_Horizonte__Minas_Gerais__Br
Benevento__Campania
Bergamo__Lombardia
Berlino__Germania
Berna__Canton_Berna__Svizzera
Berra__Emilia_Romagna
Bertinoro__Emilia_Romagna
Besozzo__Lombardia
Bibbona__Toscana
Bielefeld__Nordrhein_Westfalen
Birmingham__Inghilterra__Regno_U
Bitonto__Puglia
Boca_Chica__Santo_Domingo_Provin
VAR87
Bologna__Emilia_Romagna
Bolzano__Trentino_Alto_Adige
Bonate_di_Sopra__Lombardia
Borgo_Maggiore__Emilia_Romagna
Borgo_San_Lorenzo__Toscana
Borgomanero__Piemonte
Bormio__Lombardia
Bosaro__Veneto
Boulange__Lorraine
Bracciano__Lazio
Bratislava__Regione_di_Bratislav
VAR99
Brescia__Lombardia
Breslavia__Voivodato_della_Bassa
Bridgetown__Saint_Michael__Barba
VAR103
Brindisi__Puglia
Brisbane__Queensland__Australia
Brisighella__Emilia_Romagna
Bristol__Inghilterra__Regno_Unit
Bronte
Bucarest__Romania
Buccino__Campania
Budapest__Ungheria
Budrio__Emilia_Romagna
Buenos_Aires__Argentina
VAR114
Busseto__Emilia_Romagna
Busto_Arsizio__Lombardia
VAR117
Cabo_Frio__Rio_de_Janeiro__stato
Caccuri__Calabria
Cadoneghe__Veneto
Cagliari__Sardegna
Caivano__Campania
Calolziocorte__Lombardia
Cambiago__Lombardia
Camparada__Lombardia
Campitello__Trentino_Alto_Adige
Campobasso__Molise
Canosa_di_Puglia__Puglia
VAR129
Cantalice__Lazio
Capo_d_Orlando
Capoliveri__Toscana
Caprarola__Lazio
Capua__Campania
Caracas__Distretto_Capitale__Ven
Carpi__Emilia_Romagna
VAR137
Carugate__Lombardia
Casablanca__Grande_Casablanca__M
Casalbordino__Abruzzo
Casale_Monferrato__Piemonte
Casalecchio_di_Reno__Emilia_Roma
Casalgrande__Emilia_Romagna
Casalpusterlengo__Lombardia
Casatenovo__Lombardia
Casavatore__Campania
Cascina__Toscana
Caserta__Campania
Casilda__Santa_Fe__Argentina
Casirate_d_Adda__Lombardia
Cassinetta_di_Lugagnano__Lombard
Castel_Giorgio__Umbria
Castel_Guelfo_di_Bologna__Emilia
Castel_Rozzone__Lombardia
VAR155
Castelfranco_Emilia__Emilia_Roma
Castelfranco_Veneto__Veneto
Castellalto__Abruzzo
Castellammare_di_Stabia__Campani
Castellarano__Emilia_Romagna
Castellaro_Lagusello__Lombardia
Castelplanio__Marche
Castelraimondo__Marche
Casteltermini
Castiglione_dei_Pepoli__Emilia_R
Castiglione_del_Lago__Umbria
Castiraga_Vidardo__Lombardia
Castrocaro_Terme_e_Terra_del_Sol
Catania
Catanzaro__Calabria
Cattolica__Emilia_Romagna
Cavenago_d_Adda__Lombardia
Celle_Ligure__Liguria
Cento__Emilia_Romagna
Ceranesi__Liguria
Cerasolo__Emilia_Romagna
Cercino__Lombardia
Cerveteri__Lazio
Cervia__Emilia_Romagna
Cesena__Emilia_Romagna
Cesenatico__Emilia_Romagna
VAR182
VAR183
Charleroi__Vallonia__Belgio
VAR185
VAR186
Chiari__Lombardia
Chiavenna__Lombardia
Chiesanuova__Chiesanuova
Cigliano__Piemonte
Cingoli__Marche
Cinisello_Balsamo__Lombardia
Ciserano__Lombardia
Cisternino__Puglia
VAR195
VAR196
VAR197
Civitanova_Marche__Marche
Classe_Fuori__Emilia_Romagna
VAR200
Codogno__Lombardia
Collalbo__Trentino_Alto_Adige
Colle_Val_d_Elsa__Tuscany
Collecchio__Emilia_Romagna
Colle_di_Val_d_Elsa__Toscana
Collegno__Piemonte
Collofedo_di_Monte_Albano__Friul
Cologno_Monzese__Lombardia
Colonia__Germania
Colorno__Emilia_Romagna
Comacchio__Emilia_Romagna
Comas__Lima_Region
Como__Lombardia
Conakry__Guinea
Corato__Puglia
Corciano__Umbria
Cordovado__Friuli_Venezia_Giulia
Coriano__Emilia_Romagna
Cork__Contea_di_Cork__Irlanda
Cornaredo__Lombardia
VAR221
Correggio__Emilia_Romagna
Corropoli__Abruzzo
Corteolona__Lombardia
Cosenza__Calabria
VAR226
Cossano_Canavese__Piemonte
Cotonou__Dipartimento_del_Litora
Cremona__Lombardia
Cuneo__Piemonte
VAR231
Dacca__Divisione_di_Dacca__Bangl
Dervio__Lombardia
Desenzano_del_Garda__Lombardia
Deventer__Overijssel__Paesi_Bass
Domagnano__Emilia_Romagna
Dozza__Emilia_Romagna
Drammen__Buskerud__Norvegia
Dublino__Irlanda
Edimburgo__Scozia__Regno_Unito
Edolo__Lombardia
VAR242
Elmas__Sardegna
VAR244
Erden__Montana_Province
VAR246
Espoo__Uusimaa__Finlandia
VAR248
VAR249
Fabbrico__Emilia_Romagna
Fabriano__Marche
Faenza__Emilia_Romagna
Faetano__Emilia_Romagna
Fanano__Emilia_Romagna
Fano__Marche
Feltre__Veneto
Fermo__Marche
Ferrara__Emilia_Romagna
Fidenza__Emilia_Romagna
Filottrano__Marche
Finale_Emilia__Emilia_Romagna
Fiorentino__Emilia_Romagna
Firenze__Toscana
Foggia__Puglia
VAR265
Foligno__Umbria
Fombio__Lombardia
Fontanellato__Emilia_Romagna
Forbach__Francia
VAR270
VAR271
Forlimpopoli__Emilia_Romagna
Formia__Lazio
Fornovo_di_Taro__Emilia_Romagna
Fort_Myers__Florida__Stati_Uniti
Forte_dei_Marmi__Toscana
Fossombrone__Marche
Francavilla_al_Mare__Abruzzo
Francoforte_sul_Meno__Assia__Ger
Francolise__Campania
Fratta__Emilia_Romagna
Frattamaggiore__Campania
Friburgo__Svizzera
Fucecchio__Toscana
Fukuoka_shi__Fukuoka_Prefecture
Fulgazi__Chittagong_Division
VAR287
VAR288
Gabicce_Mare__Marche
Gaggio_Montano__Emilia_Romagna
Gaillon__Francia
Gallarate__Lombardia
Gallipoli__Puglia
Galway__Irlanda
Gambettola__Emilia_Romagna
VAR296
Gangi__Sicilia
VAR298
Gattatico__Emilia_Romagna
Gatteo__Emilia_Romagna
VAR301
Gemmano__Emilia_Romagna
Genova__Liguria
Gerano__Lazio
Ghetto__Emilia_Romagna
Ginevra__Canton_Ginevra__Svizzer
Ginosa__Puglia
Giulianova__Abruzzo
Giussano__Lombardia
Gloucester__Inghilterra__Regno_U
Gogdara__Khyber_Pakhtunkhwa
Gold_Coast__Queensland__Australi
Gradara__Marche
VAR314
VAR315
Graz__Stiria__Austria
Greensboro__Carolina_del_Nord__S
Grenoble__Francia
Gropello_Cairoli__Lombardia
Grosseto__Toscana
Grottaferrata__Lazio
Gstaad__Canton_Berna__Svizzera
VAR323
Gualdo_Tadino__Umbria
Guardamiglio__Lombardia
Guelph__Ontario__Canada
Hanoi__Vietnam
Haucourt_Moulaine__Lorraine
VAR329
Hermosa__Luzon_Centrale__Filippi
Herten__Germania
Hong_Kong__Hong_Kong
VAR333
Huntington_Beach__California__St
Ibadan__Oyo__Nigeria
Igea_Marina__Emilia_Romagna
Il_Cairo__Governatorato_del_Cair
Imola__Emilia_Romagna
Induno_Olona__Lombardia
VAR340
Intra__Piedmont
Istanbul__Provincia_di_Istanbul_
Ivrea__Piemonte
Jesi__Marche
VAR345
Kaatsheuvel__Brabante_Settentrio
Kamenets_Podolski__Khmelnytskyi
Kathu__Phuket
VAR349
Kent__England
VAR351
Kiev__Ucraina
Kiruna__Contea_di_Norrbotten__Sv
Kotka__Kymenlaakso__Finlandia
L_Aquila__Abruzzo
La_Lucila__Buenos_Aires
Lacchiarella__Lombardia
Lagosanto__Emilia_Romagna
Lainate__Lombardia
Lake_Lanier_Vista__Georgia
VAR361
Latiano__Puglia
Latina__Lazio
VAR364
VAR365
Lecce__Puglia
Legnano__Lombardia
Lendinara__Veneto
Lentini
Lesina__Puglia
Lessen__Wallonia
Lido_Adriano__Emilia_Romagna
Liegi__Vallonia__Belgio
Lighthouse_Point__Florida__Stati
VAR375
VAR376
Linz__Alta_Austria__Austria
Lione__Francia
Lissone__Lombardia
Livigno__Lombardia
Livorno__Toscana
Locate_Varesino__Lombardia
Lodi__Lombardia
Londra__Inghilterra__Regno_Unito
Long_Beach__California__Stati_Un
Longiano__Emilia_Romagna
Lorient__Francia
Los_Angeles__California__Stati_U
Losanna__Canton_Vaud__Svizzera
Losone__Canton_Ticino__Svizzera
Lubiana__Slovenia_Centrale__Slov
Lucca__Toscana
VAR393
Lugano__Canton_Ticino__Svizzera
Lugo__Emilia_Romagna
VAR396
VAR397
Lungavilla__Lombardia
Lurisia__Piedmont
VAR400
VAR401
VAR402
Maglie__Puglia
Magnacavallo__Lombardia
Maidenhead__Inghilterra__Regno_U
Maiolo__Emilia_Romagna
Mambrui__Coast_Province
Mandello_del_Lario__Lombardia
Manfredonia__Puglia
Mantova__Lombardia
Maranello__Emilia_Romagna
Marano_sul_Panaro__Emilia_Romagn
Mar_del_Plata__Provincia_di_Buen
Maribor__Oltredrava__Slovenia
Marina_di_Andora__Liguria
Marina_di_Massa__Tuscany
Marina_di_Ravenna__Emilia_Romagn
VAR418
VAR419
Marotta__Marche
VAR421
Martigues__Francia
Martina_Franca__Puglia
Mascali
Mascate__Governatorato_di_Mascat
Massa__Toscana
Matelica__Marche
VAR428
Meda__Lombardia
VAR430
VAR431
Melito_di_Napoli__Campania
Mendoza__Provincia_di_Mendoza__A
Merano__Trentino_Alto_Adige
Mercato_Saraceno__Emilia_Romagna
Messina
Mestrino__Veneto
Mezzolombardo__Trentino_Alto_Adi
Milano__Lombardia
Milano_Marittima__Emilia_Romagna
Milwaukee__Wisconsin__Stati_Unit
Minori__Campania
Minsk__Bielorussia
Mirandola__Emilia_Romagna
Misano_Adriatico__Emilia_Romagna
Mississauga__Ontario__Canada
Modena__Emilia_Romagna
Modica
Modugno__Puglia
Molinella__Emilia_Romagna
Monaco_di_Baviera__Baviera__Germ
Monastir__Governatorato_di_Monas
Moncalieri__Piemonte
Monghidoro__Emilia_Romagna
Monrovia__Contea_di_Montserrado_
Mons__Vallonia__Belgio
Monselice__Veneto
Montaldeo__Piemonte
Montanaro__Piemonte
Montecchio_Emilia__Emilia_Romagn
Montefiore_Conca__Emilia_Romagna
Montemiletto__Campania
Montescudo__Emilia_Romagna
Montesilvano__Abruzzo
Montesilvano_Marina__Abruzzo
Montespertoli__Toscana
Montevideo__Dipartimento_di_Mont
Montichiari__Lombardia
Monza__Lombardia
Morciano_di_Romagna__Emilia_Roma
Mosca__Russia
Mostar__Bosnia_ed_Erzegovina
Mouscron__Vallonia__Belgio
VAR474
Napoli__Campania
Nettuno__Lazio
Neviano_degli_Arduini__Emilia_Ro
VAR478
Nizza__Francia
Nocera_Superiore__Campania
Nogara__Veneto
Nola__Campania
Nonantola__Emilia_Romagna
Novafeltria__Emilia_Romagna
Novellara__Emilia_Romagna
Nyborg__Region_of_Southern_Denma
Oakham__Inghilterra__Regno_Unito
Offagna__Marche
Oggiono__Lombardia
Olbia__Sardegna
Oldenburg__Germania
Oleggio_Castello__Piemonte
Olgiate_Comasco__Lombardia
Olivone__Canton_Ticino__Svizzera
Omegna__Piemonte
Onerahi__Northland_Region
Opera__Lombardia
Orbassano__Piemonte
Osaka__Prefettura_di_Osaka__Giap
Oslo__Norvegia
Ospedaletto__Emilia_Romagna
Ospitaletto__Lombardia
VAR503
Padova__Veneto
Pagnona__Lombardia
Palermo
Panettieri__Calabria
Paola__Calabria
Parigi__Francia
Parma__Emilia_Romagna
VAR511
Paterno__Sicilia
Patrasso__Grecia_Occidentale__Gr
Pavia__Lombardia
VAR515
Pegognaga__Lombardia
Pekanbaru__Riau__Indonesia
Pennabilli__Emilia_Romagna
VAR519
Perugia__Umbria
Pesaro__Marche
Pesaro_e_Urbino__Marche
Pescantina__Veneto
Pescara__Abruzzo
VAR525
Pettineo
Piacenza__Emilia_Romagna
Piano_di_Follo__Liguria
Piasco__Piemonte
Piedimonte_Etneo
Pietracuta__Emilia_Romagna
Pietrasanta__Toscana
Pieve_di_Cento__Emilia_Romagna
Pieve_di_Soligo__Veneto
Pineto__Abruzzo
Pioltello__Lombardia
VAR537
Pisa__Toscana
Pistoia__Toscana
Pizzighettone__Lombardia
Poggio_Berni__Emilia_Romagna
Poggio_Renatico__Emilia_Romagna
Pollutri__Abruzzo
Pontassieve__Toscana
Ponte_San_Pietro__Lombardia
Ponte_di_Legno__Lombardia
Pontevico__Lombardia
Pordenone__Friuli_Venezia_Giulia
Portici__Campania
Portogruaro__Veneto
Potenza__Basilicata
Poviglio__Emilia_Romagna
VAR553
Prato__Toscana
Prato_allo_Stelvio__Trentino_Alt
Puerto_Vallarta__Jalisco__Messic
Quartu_Sant_Elena__Sardegna
Quattordio__Piemonte
Quezon_City__Regione_Capitale_Na
VAR560
Ravenna__Emilia_Romagna
Recanati__Marche
Recife__Pernambuco__Brasile
VAR564
Regione_di_Bruxelles_Capitale__B
Renens__Canton_Vaud__Svizzera
VAR567
Rescaldina__Lombardia
VAR569
VAR570
Rho__Lombardia
Riccione__Emilia_Romagna
Rieti__Lazio
Rigolato__Friuli_Venezia_Giulia
Rimini__Emilia_Romagna
Rio_de_Janeiro__Rio_de_Janeiro__
Riolo_Terme__Emilia_Romagna
Ripa_Teatina__Abruzzo
Rivabella__Emilia_Romagna
Rivarolo_Mantovano__Lombardia
Rivazzura__Emilia_Romagna
Riverview__Michigan__Stati_Uniti
Rocchetta_Sant_Antonio__Puglia
Rochester_Hills__Michigan__Stati
Rodi_Garganico__Puglia
Rohtak__Haryana__India
Roma__Lazio
Romano_Alto__Veneto
VAR589
Rosignano_Marittimo__Toscana
Rotterdam__Paesi_Bassi
Rovereto__Trentino_Alto_Adige
Rovito__Calabria
Rozzano__Lombardia
Rutigliano__Puglia
Sal_Rei__Boa_Vista__Capo_Verde
Sala_Consilina__Campania
Salonicco__Macedonia_Centrale__G
Salsomaggiore_Terme__Emilia_Roma
Saludecio__Emilia_Romagna
San_Benedetto_del_Tronto__Marche
VAR602
San_Biagio__Lombardia
San_Clemente__Emilia_Romagna
San_Colombano_al_Lambro__Lombard
San_Diego__California__Stati_Uni
San_Francisco__California__Stati
San_Genaro__Santa_Fe
San_Giovanni_Lupatoto__Veneto
San_Giovanni_Teatino__Abruzzo
San_Giovanni_in_Marignano__Emili
San_Giovanni_in_Persiceto__Emili
San_Giuliano__Emilia_Romagna
San_Giuliano__Malta
SanGiuliano_a_Mare__Emilia_Romag
San_Lazzaro_di_Savena__Emilia_Ro
San_Leo__Emilia_Romagna
San_Marco_dei_Cavoti__Campania
VAR619
San_Mauro_Pascoli__Emilia_Romagn
SanMauro_a_Mare__Emilia_Romagna
San_Paolo__Lombardia
San_Pietro_Vernotico__Puglia
San_Prisco__Campania
San_Salvo__Abruzzo
San_Savino__Marche
San_Terenzo__Liguria
VAR628
San_Vito_Rimini__Emilia_Romagna
San_Vito_al_Tagliamento__Friuli_
San_Vito_di_Cadore__Veneto
Sansepolcro__Toscana
VAR633
VAR634
VAR635
Sant_Angelo_Lodigiano__Lombardia
Sant_Angelo_dei_Lombardi__Campan
Sant_Egidio_alla_Vibrata__Abruzz
Sant_Elpidio_a_Mare__Marche
Santa_Bianca__Emilia_Romagna
Santa_Cesarea_Terme__Puglia
Santa_Fe__Argentina
Santa_Giustina__Emilia_Romagna
Santa_Venerina
Santarcangelo__Emilia_Romagna
Santarcangelo_di_Romagna__Emilia
Santeramo_in_Colle__Puglia
Santiago_del_Cile__Regione_Metro
Sarno__Campania
Sarzana__Liguria
Sassari__Sardegna
Sasso_Feltrio__Marche
Sasso_Marconi__Emilia_Romagna
Sassuolo__Emilia_Romagna
Savignano_sul_Rubicone__Emilia_R
Savona__Liguria
Scampitella__Campania
Scandiano__Emilia_Romagna
Scandicci__Toscana
Scarperia_e_San_Piero__Toscana
Schafisheim__Canton_Argovia__Svi
Sciaffusa__Svizzera
Scicli
Selvatelle__Tuscany
Senigallia__Marche
Senta__Serbia
Seregno__Lombardia
Sergnano__Lombardia
VAR669
Settimo_Milanese__Lombardia
Seveso__Lombardia
Siena__Toscana
VAR673
Siracusa
Siviglia__Andalusia__Spagna
VAR676
Skawina__Lesser_Poland_Voivodesh
VAR678
Sofia__Bulgaria
Solarolo__Emilia_Romagna
Soletta__Svizzera
Solto_Collina__Lombardia
Soriano_nel_Cimino__Lazio
Sortino
South_Milwaukee__Wisconsin__Stat
Soverato__Calabria
Soveria_Simeri__Calabria
Spinea__Veneto
Spoleto__Umbria
Spormaggiore__Trentino_Alto_Adig
VAR691
Stanghella__Veneto
VAR693
Stoccolma__Contea_di_Stoccolma_
Stony_Plain__Alberta
Strasburgo__Alsazia__Francia
Striano__Campania
Sustinente__Lombardia
Suvereto__Toscana
Sydney__Nuovo_Galles_del_Sud__Au
Szczyrzyc__Voivodato_della_Picco
VAR702
Tainan__Taiwan
Talamello__Emilia_Romagna
VAR705
Taranto__Puglia
Taurisano__Puglia
Taverna__Emilia_Romagna
Tavullia__Marche
Tenerife__Isole_Canarie__Spagna
Teramo__Abruzzo
Termini_Imerese
Ternate__Lombardia
Terni__Umbria
Terracina__Lazio
Terricciola__Toscana
VAR717
VAR718
Tirana__Prefettura_di_Tirana__Al
VAR720
Tlalnepantla_de_Comonfort__State
VAR722
Torino__Piemonte
Torre_Annunziata__Campania
Torre_Pedrera__Emilia_Romagna
Torriana__Emilia_Romagna
Trabia
Trecate__Piemonte
Trecchina__Basilicata
Trento__Trentino_Alto_Adige
Tres_Cantos__Comunidad_de_Madrid
Treviglio__Lombardia
Treviso__Veneto
Trieste__Friuli_Venezia_Giulia
Trikala__Grecia
Triuggio__Lombardia
Truccazzano__Lombardia
VAR738
Tunisi__Governatorato_di_Tunisi_
Udine__Friuli_Venezia_Giulia
Ulan_Bator__Mongolia
Umbertide__Umbria
Urbania__Marche
Urbino__Marche
Utrecht__Paesi_Bassi
VAR746
Valentano__Lazio
Valle_Lomellina__Lombardia
Vanderbijlpark__Gauteng__Sudafri
Varese__Lombardia
Vedelago__Veneto
Venaria_Reale__Piemonte
Venezia__Veneto
Vercelli__Piemonte
Vergiano__Emilia_Romagna
Verona__Veneto
Verucchio__Emilia_Romagna
Viano__Emilia_Romagna
Vibo_Valentia__Calabria
Vicenza__Veneto
Vico_del_Gargano__Puglia
Vigasio__Veneto
Vigevano__Lombardia
Vignate__Lombardia
Villa_General_Belgrano__Provinci
Villa_Verucchio__Emilia_Romagna
VAR767
VAR768
Vinchiaturo__Molise
Viserba__Emilia_Romagna
Viserbella__Emilia_Romagna
Voghera__Lombardia
Wakefield__Inghilterra__Regno_Un
Washington__Stati_Uniti_d_Americ
Wellfleet__Massachusetts__Stati
Woerden__Utrecht__Paesi_Bassi
VAR777
Yokohama__Prefettura_di_Kanagawa
Yorktown__Virginia__Stati_Uniti
VAR780
Zacharo__Grecia_Occidentale__Gre
Zapponeta__Puglia
Zola_Predosa__Emilia_Romagna
Zurigo__Canton_Zurigo__Svizzera
/ BOX="31 Daily City People Talking";
RUN;      


/**************************************************************************/
/* 34 NUMERO DI PERSONE CHE PARLANO DELLA PAGINA PER LINGUA AL GIORNO     */
/**************************************************************************/
TITLE3 "#34 Giornaliero: il numero di persone che parlano della Pagina suddivise per lingua. (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_language_people_talk_34
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Language People Talkin...";
RUN;

proc TABULATE data=facebook.daily_language_people_talk_34 format=comma10. ;
CLASS Data;
VAR
ar_AR
bg_BG
bn_IN
bp_IN
bs_BA
cs_CZ
da_DK
de_DE
el_GR
en_GB
en_US
es_ES
es_LA
fa_IR
fi_FI
fr_FR
gx_GR
he_IL
hr_HR
hu_HU
id_ID
it_IT
ja_JP
ko_KR
lt_LT
mk_MK
nb_NO
nl_BE
nl_NL
pl_PL
pt_BR
pt_PT
ro_RO
ru_RU
sk_SK
sl_SI
sq_AL
sr_RS
sv_SE
th_TH
tr_TR
uk_UA
vi_VN
zh_CN
zh_HK
zh_TW;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
      TABLE
      Data all, ar_AR
bg_BG
bn_IN
bp_IN
bs_BA
cs_CZ
da_DK
de_DE
el_GR
en_GB
en_US
es_ES
es_LA
fa_IR
fi_FI
fr_FR
gx_GR
he_IL
hr_HR
hu_HU
id_ID
it_IT
ja_JP
ko_KR
lt_LT
mk_MK
nb_NO
nl_BE
nl_NL
pl_PL
pt_BR
pt_PT
ro_RO
ru_RU
sk_SK
sl_SI
sq_AL
sr_RS
sv_SE
th_TH
tr_TR
uk_UA
vi_VN
zh_CN
zh_HK
zh_TW
      / BOX="34 Daily Language People Talkin";
RUN;


/**************************************************************************/
/* 37 TAB VISUALIZZATE DAGLI UTENTI AL GIORNO                             */
/**************************************************************************/
TITLE3 "#37 Al giorno: tab nella tua Pagina visualizzate quando gli utenti che hanno effettuato l'accesso hanno visitato la tua Pagina. (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_logged_intab_views_37
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Logged-in Tab Views";
RUN;

proc TABULATE data=facebook.daily_logged_intab_views_37 FORMAT=COMMA10.;
CLASS Data;
VAR about
album
albums
allactivity
community
custom
events
home
notes
page_info
photos
posts
profile
profile_about
profile_community
profile_events
profile_home
profile_info
profile_notes
profile_photos
profile_posts
profile_reviews
profile_videos
reviews
timeline
videos
;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
      TABLE
Data all, about
album
albums
allactivity
community
custom
events
home
notes
page_info
photos
posts
profile
profile_about
profile_community
profile_events
profile_home
profile_info
profile_notes
profile_photos
profile_posts
profile_reviews
profile_videos
reviews
timeline
videos 
      / BOX="37 Daily Logged-in Tab Views (UTENTI UNICI)";
RUN;

/**************************************************************************/
/* 38 DOMINI ESTERNI DI REINDIRIZZAMENTO PRINCIPALI AL GIORNO             */
/**************************************************************************/

TITLE3 "#38 Al giorno: domini esterni di reindirizzamento principali che inviano traffico alla tua Pagina (Numero totale)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_external_referrers_38
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily External Referrers";
RUN;

proc TABULATE data=facebook.daily_external_referrers_38 FORMAT=COMMA10.;
CLASS Data;
VAR 
VAR3
VAR4
VAR5
VAR6
VAR7
VAR8
VAR9
VAR10
VAR11
VAR12
VAR13
VAR14
VAR15
VAR16
VAR17
VAR18
VAR19
VAR20
VAR21
VAR22
VAR23
VAR24
VAR25
VAR26
VAR27
VAR28
VAR29
VAR30
VAR31
VAR32
VAR33
VAR34
VAR35
VAR36
VAR37
VAR38
VAR39
VAR40
VAR41
VAR42
VAR43
VAR44
VAR45
VAR46
VAR47
VAR48
VAR49
VAR50
VAR51
VAR52
VAR53
VAR54
VAR55
VAR56
VAR57
VAR58
VAR59
VAR60
VAR61
VAR62
VAR63
VAR64
VAR65
VAR66
VAR67
VAR68
VAR69
VAR70
VAR71
VAR72
VAR73
VAR74
VAR75
VAR76
VAR77
VAR78
VAR79
VAR80
VAR81
VAR82
VAR83
VAR84
VAR85
VAR86
VAR87
VAR88
VAR89
VAR90
VAR91
VAR92
VAR93
VAR94
VAR95
VAR96
VAR97
VAR98
VAR99
VAR100
VAR101
VAR102
VAR103
VAR104
VAR105
VAR106
VAR107
VAR108
VAR109
VAR110
VAR111
VAR112
VAR113
VAR114
VAR115
VAR116
VAR117
VAR118
VAR119
VAR120
VAR121
VAR122
VAR123
VAR124
VAR125
VAR126
VAR127
VAR128
VAR129
VAR130
VAR131
VAR132
VAR133
VAR134
VAR135
VAR136
VAR137
VAR138
VAR139
VAR140
VAR141
VAR142
VAR143
VAR144
VAR145
VAR146
VAR147
VAR148
VAR149
VAR150
VAR151
VAR152
VAR153
VAR154
VAR155
VAR156
VAR157
VAR158
VAR159
VAR160
VAR161
VAR162
VAR163
VAR164
VAR165
VAR166
VAR167
VAR168
VAR169
VAR170
VAR171
VAR172
VAR173
VAR174
VAR175
VAR176
VAR177
VAR178
VAR179
VAR180
VAR181
VAR182
VAR183
VAR184
VAR185
VAR186
VAR187
VAR188
VAR189
VAR190
VAR191
VAR192
VAR193
VAR194
VAR195
VAR196
VAR197
VAR198
VAR199
VAR200
VAR201
VAR202
VAR203
VAR204
VAR205
VAR206
VAR207
VAR208
VAR209
VAR210
VAR211
VAR212
VAR213
VAR214
VAR215
VAR216
VAR217
VAR218
VAR219
VAR220
VAR221
VAR222
VAR223
VAR224
VAR225
VAR226
VAR227
VAR228
VAR229
VAR230
VAR231
VAR232
VAR233
VAR234
VAR235
VAR236
VAR237
VAR238
VAR239
VAR240
VAR241
VAR242
VAR243
VAR244
VAR245
VAR246
VAR247
VAR248
VAR249
VAR250
VAR251
VAR252
VAR253
VAR254
VAR255
VAR256
VAR257
VAR258
VAR259
VAR260
VAR261
VAR262
VAR263
VAR264
VAR265
VAR266
VAR267
VAR268
VAR269
VAR270
VAR271
VAR272
VAR273
VAR274
VAR275
VAR276
VAR277
VAR278
VAR279
VAR280
VAR281
VAR282
VAR283
VAR284
VAR285
VAR286
VAR287
VAR288
VAR289
VAR290
VAR291
;
KEYLABEL n="N" all="TOTALE";
LABEL 
VAR3="Http://arianna.libero.it/web/ricerca?f=hp&qs=comune+rimini+faceb"
VAR4="http://arianna.libero.it/web/ricerca?qs=+comune+di+rimini&f=us"
VAR5="http://arianna.libero.it/web/ricerca?qs=comune+di+rimini&f=us"
VAR6="http://arianna.libero.it/web/ricerca?qs=comune+rimini&f=us"
VAR7="http://icalighieri.gov.it/ai-genitori-alunni-e-doceni-dellic-ali"
VAR8="http://int.search.myway.com/search/GGmain.jhtml?p2=%5EUX%5Expv42"
VAR9="http://int.search.myway.com/search/GGmain.jhtml?searchfor=+neve+"
VAR10="http://mistermedia.it/pubblica-amministrazione-social-customer-c"
VAR11="http://paoloratto.com/2013/02/pagina-facebook-policy.html"
VAR12="http://www.bing.com/search?pc=COSP&ptag=D013018-A21ABFDD9D88F416"
VAR13="http://www.comune.rimini.it/"
VAR14="http://www.comune.rimini.it/agenda/pagina1430.html"
VAR15="http://www.comune.rimini.it/archivio-eventi?field_data_value%5Bv"
VAR16="http://www.comune.rimini.it/archivio-notizie"
VAR17="http://www.comune.rimini.it/archivio-notizie/agenda-digitale-al-"
VAR18="http://www.comune.rimini.it/archivio-notizie/aperta-alla-corte-m"
VAR19="http://www.comune.rimini.it/archivio-notizie/cinema-fulgor-sabat"
VAR20="http://www.comune.rimini.it/archivio-notizie/da-hera-riceviamo-e"
VAR21="http://www.comune.rimini.it/archivio-notizie/dichiarazione-della"
VAR22="http://www.comune.rimini.it/archivio-notizie/elezioni-politiche-"
VAR23="http://www.comune.rimini.it/archivio-notizie/fabbrica-arte-rimin"
VAR24="http://www.comune.rimini.it/archivio-notizie/il-teatro-galli-ha-"
VAR25="http://www.comune.rimini.it/archivio-notizie/inaugurazione-cinem"
VAR26="http://www.comune.rimini.it/archivio-notizie/lassistente-famigli"
VAR27="http://www.comune.rimini.it/archivio-notizie/maltempo-150-i-mm-d"
VAR28="http://www.comune.rimini.it/archivio-notizie/maltempo-ancora-ghi"
VAR29="http://www.comune.rimini.it/archivio-notizie/maltempo-continua-c"
VAR30="http://www.comune.rimini.it/archivio-notizie/progetto-tiberio-pr"
VAR31="http://www.comune.rimini.it/archivio-notizie/vaccinazioni-obblig"
VAR32="http://www.comune.rimini.it/archivio-notizie?field_data_value%5B"
VAR33="http://www.comune.rimini.it/casadei-marco-cessato-il-16062016"
VAR34="http://www.comune.rimini.it/comune-e-citta/citta/arengo-online"
VAR35="http://www.comune.rimini.it/comune-e-citta/citta/arengo/emergenz"
VAR36="http://www.comune.rimini.it/comune-e-citta/citta/arengo/quaderni"
VAR37="http://www.comune.rimini.it/comune-e-citta/citta/monumenti/ponte"
VAR38="http://www.comune.rimini.it/comune-e-citta/comune/canile-e-anagr"
VAR39="http://www.comune.rimini.it/comune-e-citta/comune/canile-e-anagr_1"
VAR40="http://www.comune.rimini.it/comune-e-citta/comune/centro-le-fami"
VAR41="http://www.comune.rimini.it/comune-e-citta/comune/centro-le-fami_1"
VAR42="http://www.comune.rimini.it/comune-e-citta/comune/concorsi"
VAR43="http://www.comune.rimini.it/comune-e-citta/comune/concorsi/conco"
VAR44="http://www.comune.rimini.it/comune-e-citta/comune/elenco-complet"
VAR45="http://www.comune.rimini.it/comune-e-citta/comune/elenco-complet_1"
VAR46="http://www.comune.rimini.it/comune-e-citta/comune/elenco-complet_2"
VAR47="http://www.comune.rimini.it/comune-e-citta/comune/elenco-complet_3"
VAR48="http://www.comune.rimini.it/comune-e-citta/comune/elettorale"
VAR49="http://www.comune.rimini.it/comune-e-citta/comune/elettorale/spe"
VAR50="http://www.comune.rimini.it/comune-e-citta/comune/la-casa-delle-"
VAR51="http://www.comune.rimini.it/comune-e-citta/comune/la-casa-delle-_1"
VAR52="http://www.comune.rimini.it/comune-e-citta/comune/mobilita/trasp"
VAR53="http://www.comune.rimini.it/comune-e-citta/comune/oggetti-rinven"
VAR54="http://www.comune.rimini.it/comune-e-citta/comune/passi-carrabil"
VAR55="http://www.comune.rimini.it/comune-e-citta/comune/politiche-abit"
VAR56="http://www.comune.rimini.it/comune-e-citta/comune/relazioni-con-"
VAR57="http://www.comune.rimini.it/comune-e-citta/comune/scuola-e-servi"
VAR58="http://www.comune.rimini.it/comune-e-citta/comune/scuola-servizi"
VAR59="http://www.comune.rimini.it/comune-e-citta/comune/scuola-servizi_1"
VAR60="http://www.comune.rimini.it/comune-e-citta/comune/scuola-servizi_2"
VAR61="http://www.comune.rimini.it/comune-e-citta/comune/scuola-servizi_3"
VAR62="http://www.comune.rimini.it/comune-e-citta/comune/scuola-servizi_4"
VAR63="http://www.comune.rimini.it/comune-e-citta/comune/scuola-servizi_5"
VAR64="http://www.comune.rimini.it/comune-e-citta/comune/scuola-servizi_6"
VAR65="http://www.comune.rimini.it/comune-e-citta/comune/scuola-servizi_7"
VAR66="http://www.comune.rimini.it/comune-e-citta/comune/scuola-servizi_8"
VAR67="http://www.comune.rimini.it/comune-e-citta/comune/sport-riminisp"
VAR68="http://www.comune.rimini.it/comune-e-citta/comune/sport-riminisp_1"
VAR69="http://www.comune.rimini.it/comune-e-citta/comune/sport-riminisp_2"
VAR70="http://www.comune.rimini.it/comune-e-citta/comune/sport/calendar"
VAR71="http://www.comune.rimini.it/comune-e-citta/comune/sportello-ledi"
VAR72="http://www.comune.rimini.it/comune-e-citta/comune/sportello-ledi_1"
VAR73="http://www.comune.rimini.it/comune-e-citta/comune/sportello-ledi_2"
VAR74="http://www.comune.rimini.it/comune-e-citta/comune/statistiche-e-"
VAR75="http://www.comune.rimini.it/comune-e-citta/comune/ufficio-relazi"
VAR76="http://www.comune.rimini.it/comune-e-citta/comune/ufficio-relazi_1"
VAR77="http://www.comune.rimini.it/comune-e-citta/comune/ufficio-relazi_2"
VAR78="http://www.comune.rimini.it/comune-e-citta/comune/ufficio-relazi_3"
VAR79="http://www.comune.rimini.it/comune-e-citta/comune/ufficio-relazi_4"
VAR80="http://www.comune.rimini.it/comune-e-citta/comune/ufficio-relazi_5"
VAR81="http://www.comune.rimini.it/comune-e-citta/comune/ufficio-relazi_6"
VAR82="http://www.comune.rimini.it/comune-e-citta/comune/ufficio-relazi_7"
VAR83="http://www.comune.rimini.it/comune-e-citta/comune/ufficio-relazi_8"
VAR84="http://www.comune.rimini.it/comune-e-citta/comune/ufficio-relazi_9"
VAR85="http://www.comune.rimini.it/comune-e-citta/comune/ufficio-relazi_10"
VAR86="http://www.comune.rimini.it/concorso-2018-114-1-concorso-pubblic"
VAR87="http://www.comune.rimini.it/concorso1141-educatore-nido-dinfanzi"
VAR88="http://www.comune.rimini.it/consiglio-comunale-seduta-n-01-13"
VAR89="http://www.comune.rimini.it/contatti"
VAR90="http://www.comune.rimini.it/cookie-policy"
VAR91="http://www.comune.rimini.it/cultura-e-turismo/cultura/far"
VAR92="http://www.comune.rimini.it/elenco-telefonico/dellavalle-alberto"
VAR93="http://www.comune.rimini.it/eventi/pagina9277.html?fb_action_ids"
VAR94="http://www.comune.rimini.it/file/bicipolitanajpg-1"
VAR95="http://www.comune.rimini.it/newsletter/signup"
VAR96="http://www.comune.rimini.it/ordinanza-sindacale-qualita-dellaria"
VAR97="http://www.comune.rimini.it/privacy"
VAR98="http://www.comune.rimini.it/search/content/"
VAR99="http://www.comune.rimini.it/search/content/Mercatini%20a%20marso"
VAR100="http://www.comune.rimini.it/search/content/Scuole%20neve"
VAR101="http://www.comune.rimini.it/search/content/centralino"
VAR102="http://www.comune.rimini.it/sites/comune.rimini.it/files/lista_d"
VAR103="http://www.google.com/"
VAR104="http://www.google.de/search?q=sindaco+di+rimini+2017&oq=sindaco+"
VAR105="http://www.google.es/"
VAR106="http://www.google.it/"
VAR107="http://www.google.it/search?client=safari&rls=en&q=comune+rimini"
VAR108="http://www.google.it/search?ei=46mWWrDJMODwgAa0uLLoBQ&q=comune+d"
VAR109="http://www.google.it/search?ei=ECCYWoqJBcfWUa2zhuAO&q=rimini+com"
VAR110="http://www.google.it/search?ei=MJGWWvaHIoaRUa65r9AK&q=comune+di+"
VAR111="http://www.google.it/search?ei=nRiYWvi6C4W6Uq-BgbAK&q=comune+di+"
VAR112="http://www.google.it/search?hl=it&redir_esc&client=ms-android-hm"
VAR113="http://www.google.it/search?hl=it&redir_esc&client=ms-android-sa"
VAR114="http://www.google.it/search?q=Comune+rimini&oq=Comune+rimini&gs_"
VAR115="http://www.google.it/search?q=comune+di+rimini&oq&gs_l=mobile-he"
VAR116="http://www.google.it/search?q=comune+di+rimini&oq=co&gs_l=mobile"
VAR117="http://www.google.it/search?q=comune+di+rimini&oq=co&gs_l=mobile_1"
VAR118="http://www.google.it/search?q=comune+di+rimini&oq=co&gs_l=mobile_2"
VAR119="http://www.google.it/search?q=comune+di+rimini&oq=co&gs_l=mobile_3"
VAR120="http://www.google.it/search?q=comune+di+rimini&oq=co&gs_l=mobile_4"
VAR121="http://www.google.it/search?q=comune+di+rimini&oq=co&gs_l=mobile_5"
VAR122="http://www.google.it/search?q=comune+di+rimini&oq=co&gs_l=mobile_6"
VAR123="http://www.google.it/search?q=comune+di+rimini&oq=com&gs_l=mobil"
VAR124="http://www.google.it/search?q=comune+di+rimini&oq=com&gs_l=mobil_1"
VAR125="http://www.google.it/search?q=comune+di+rimini&oq=comu&gs_l=mobi"
VAR126="http://www.google.it/search?q=comune+di+rimini&oq=comu&gs_l=mobi_1"
VAR127="http://www.google.it/search?q=comune+di+rimini&oq=comu&gs_l=mobi_2"
VAR128="http://www.google.it/search?q=comune+di+rimini&oq=comu&gs_l=mobi_3"
VAR129="http://www.google.it/search?q=comune+di+rimini&oq=comu&gs_l=mobi_4"
VAR130="http://www.google.it/search?q=comune+di+rimini&oq=comu&gs_l=mobi_5"
VAR131="http://www.google.it/search?q=comune+di+rimini&oq=comu&gs_l=mobi_6"
VAR132="http://www.google.it/search?q=comune+di+rimini&oq=comune&gs_l=mo"
VAR133="http://www.google.it/search?q=comune+di+rimini&oq=comune&gs_l=mo_1"
VAR134="http://www.google.it/search?q=comune+di+rimini+facebook&dcr=0&oq"
VAR135="http://www.google.it/search?q=comune+di+rimini+facebook&gws_rd=c"
VAR136="http://www.google.it/search?q=comune+di+rimini+facebook&gws_rd=c_1"
VAR137="http://www.google.it/search?q=comune+di+rimini+facebook&oq=c&gs_"
VAR138="http://www.google.it/search?q=comune+di+rimini+facebook&oq=c&gs__1"
VAR139="http://www.google.it/search?q=comune+di+rimini+facebook&oq=co&gs"
VAR140="http://www.google.it/search?q=comune+di+rimini+facebook&oq=co&gs_1"
VAR141="http://www.google.it/search?q=comune+di+rimini+facebook&oq=comu&"
VAR142="http://www.google.it/search?q=comune+di+rimini+facebook&oq=comun"
VAR143="http://www.google.it/search?q=comune+di+rimini+facebook&oq=comun_1"
VAR144="http://www.google.it/search?q=comune+di+rimini+facebook&oq=comun_2"
VAR145="http://www.google.it/search?q=comune+di+rimini+facebook&oq=comun_3"
VAR146="http://www.google.it/search?q=comune+rimini+scuole+chiuse&dcr=0&"
VAR147="http://www.google.it/search?q=www.comunedi+rimini&gws_rd=cr&dcr="
VAR148="http://www.google.it/search?source=hp&ei=4kCUWpTPEobTkwXpvKaQCg&"
VAR149="http://www.google.it/search?source=hp&ei=GfFJWpjqI4SYkwXeub6oCw&"
VAR150="http://www.icxxsettembrerimini.gov.it/"
VAR151="http://www.itigrimini.it/"
VAR152="http://www.meteobellaria.it/stazione1/index.php"
VAR153="http://www.paoloratto.com/2013/02/pagina-facebook-policy.html"
VAR154="http://www.riminiturismo.it/"
VAR155="http://www.riminiturismo.it/chi-siamo"
VAR156="http://www.riminiturismo.it/contatti"
VAR157="http://www.riminiturismo.it/en"
VAR158="http://www.riminiturismo.it/en/events-news/rimining-things-do-20"
VAR159="http://www.riminiturismo.it/en/tourist-information"
VAR160="http://www.riminiturismo.it/en/visitatori/eventi/manifestazioni-"
VAR161="http://www.riminiturismo.it/en/visitatori/eventi/manifestazioni-_1"
VAR162="http://www.riminiturismo.it/en/visitatori/scopri-il-territorio/p"
VAR163="http://www.riminiturismo.it/eventi-notizie"
VAR164="http://www.riminiturismo.it/eventi-notizie/20-gennaio-2018-buon-"
VAR165="http://www.riminiturismo.it/eventi-notizie/cose-da-fare-rimini-s"
VAR166="http://www.riminiturismo.it/eventi-notizie/lumen-la-cappella-dei"
VAR167="http://www.riminiturismo.it/eventi-notizie/rimining-cose-da-fare"
VAR168="http://www.riminiturismo.it/press/comunicati-stampa"
VAR169="http://www.riminiturismo.it/richiedi-il-kit-del-viaggiatore"
VAR170="http://www.riminiturismo.it/visitatori/come-arrivare/collegament"
VAR171="http://www.riminiturismo.it/visitatori/eventi/manifestazioni-e-i"
VAR172="http://www.riminiturismo.it/visitatori/eventi/manifestazioni-e-i_1"
VAR173="http://www.riminiturismo.it/visitatori/eventi/manifestazioni-e-i_2"
VAR174="http://www.riminiturismo.it/visitatori/eventi/manifestazioni-e-i_3"
VAR175="http://www.riminiturismo.it/visitatori/eventi/manifestazioni-e-i_4"
VAR176="http://www.riminiturismo.it/visitatori/eventi/manifestazioni-e-i_5"
VAR177="http://www.riminiturismo.it/visitatori/eventi/manifestazioni-e-i_6"
VAR178="http://www.riminiturismo.it/visitatori/eventi/manifestazioni-e-i_7"
VAR179="http://www.riminiturismo.it/visitatori/eventi/manifestazioni-e-i_8"
VAR180="http://www.riminiturismo.it/visitatori/eventi/manifestazioni-e-i_9"
VAR181="http://www.riminiturismo.it/visitatori/eventi/manifestazioni-e-i_10"
VAR182="http://www.riminiturismo.it/visitatori/eventi/manifestazioni-e-i_11"
VAR183="http://www.riminiturismo.it/visitatori/eventi/manifestazioni-e-i_12"
VAR184="http://www.riminiturismo.it/visitatori/eventi/manifestazioni-e-i_13"
VAR185="http://www.riminiturismo.it/visitatori/ospitalita/dove-dormire"
VAR186="http://www.riminiturismo.it/visitatori/ospitalita/dove-mangiare/"
VAR187="http://www.riminiturismo.it/visitatori/ospitalita/dove-mangiare/_1"
VAR188="http://www.riminiturismo.it/visitatori/scopri-il-territorio/ambi"
VAR189="http://www.riminiturismo.it/visitatori/scopri-il-territorio/itin"
VAR190="http://www.urlopener.com/homepage.html"
VAR191="https://duckduckgo.com/"
VAR192="https://fr.search.yahoo.com/"
VAR193="https://int.search.myway.com/search/GGmain.jhtml?ct=ARS&n=--sani"
VAR194="https://it.search.yahoo.com/"
VAR195="https://m.altarimini.it/News77606-rimini-asta-oggetti-rinvenuti-"
VAR196="https://mail.google.com/mail/u/0/?ui=2&ik=cb6c0e959a&view=lg&msg"
VAR197="https://wm34.email.it/webmail/wm_5/readmsg.php?us=ZHRvc2lAZW1haW"
VAR198="https://www.altarimini.it/News77606-rimini-asta-oggetti-rinvenut"
VAR199="https://www.bing.com/"
VAR200="https://www.bing.com/search?q=comune+di+rimini&FORM=EDGENA"
VAR201="https://www.bing.com/search?q=comune+di+rimini&FORM=EDGENN"
VAR202="https://www.bing.com/search?q=comune+di+rimini&form=APIPH1&PC=AP"
VAR203="https://www.bing.com/search?q=comune+di+rimini&form=MB1078&mkt=i"
VAR204="https://www.bing.com/search?q=comune+di+rimini&input=5&form=MB10"
VAR205="https://www.bing.com/search?q=comune+di+rimini&pivot=web&mkt=it-"
VAR206="https://www.bing.com/search?q=comune+di+rimini&pr=1&cuid=%7B7B20"
VAR207="https://www.bing.com/search?q=comune+di+rimini&pr=1&cuid=%7BD45A"
VAR208="https://www.bing.com/search?q=comune+di+rimini&qs=n&form=QBRE&sp"
VAR209="https://www.bing.com/search?q=comune+di+rimini+facebook&form=MB1"
VAR210="https://www.bing.com/search?q=comune+di+rimini+facebook&qs=SC&pq"
VAR211="https://www.bing.com/search?q=comune+rimini&FORM=EDGENA"
VAR212="https://www.bing.com/search?q=comune+rimini&form=MB1078&mkt=it-I"
VAR213="https://www.bing.com/search?q=comune+rimini+facebook&form=MB1078"
VAR214="https://www.bing.com/search?q=coune+rimini+facebook&form=MB1078&"
VAR215="https://www.bing.com/search?q=facebook+comune+rimini&input=1&for"
VAR216="https://www.bing.com/search?q=rimini+facebook&form=MB1078&mkt=it"
VAR217="https://www.comune.riccione.rn.it/"
VAR218="https://www.ecosia.org/"
VAR219="https://www.google.ae/"
VAR220="https://www.google.al/"
VAR221="https://www.google.co.uk/"
VAR222="https://www.google.co.ve/"
VAR223="https://www.google.com.ar/"
VAR224="https://www.google.com.ar/search?q=comuna+de+rimini+italia&oq=co"
VAR225="https://www.google.com.br/"
VAR226="https://www.google.com.hk/"
VAR227="https://www.google.com.np/"
VAR228="https://www.google.com.ua/"
VAR229="https://www.google.com/"
VAR230="https://www.google.com/search?oe=utf-8&safe=images&hl=it-IT&clie"
VAR231="https://www.google.de/"
VAR232="https://www.google.es/"
VAR233="https://www.google.fr/"
VAR234="https://www.google.gr/"
VAR235="https://www.google.hu/"
VAR236="https://www.google.it/"
VAR237="https://www.google.it/search?biw=360&bih=287&ei=HESZWqGqJ8a5kwXS"
VAR238="https://www.google.it/search?client=ms-android-huawei&dcr=0&ei=o"
VAR239="https://www.google.it/search?client=ms-android-huawei&ei=Nj2UWuj"
VAR240="https://www.google.it/search?client=ms-android-huawei&ei=t76XWuK"
VAR241="https://www.google.it/search?client=ms-android-samsung&ei=goqWWu"
VAR242="https://www.google.it/search?client=ms-android-samsung&ei=rrOWWq"
VAR243="https://www.google.it/search?client=ms-android-samsung&hl=it-IT&"
VAR244="https://www.google.it/search?oe=utf-8&hl=it-IT&client=ms-android"
VAR245="https://www.google.it/search?pws=0&action=devloc&hl=it&safe=imag"
VAR246="https://www.google.it/search?q=+comune+di+rimini+&client=firefox"
VAR247="https://www.google.it/search?q=acomune+di.rimini&oq=acomune+di.r"
VAR248="https://www.google.it/search?q=comune+di+rimini&client=ms-androi"
VAR249="https://www.google.it/search?q=comune+di+rimini&client=ms-androi_1"
VAR250="https://www.google.it/search?q=comune+di+rimini&ie&oe"
VAR251="https://www.google.it/search?q=comune+di+rimini&ie=utf-8&oe=utf-"
VAR252="https://www.google.it/search?q=comune+di+rimini&ie=utf-8&oe=utf-_1"
VAR253="https://www.google.it/search?q=comune+di+rimini&ie=utf-8&oe=utf-_2"
VAR254="https://www.google.it/search?q=comune+di+rimini&ie=utf-8&oe=utf-_3"
VAR255="https://www.google.it/search?q=comune+di+rimini&oq=c&aqs=chrome."
VAR256="https://www.google.it/search?q=comune+di+rimini&oq=comune&aqs=ch"
VAR257="https://www.google.it/search?q=comune+di+rimini&oq=comune+&aqs=c"
VAR258="https://www.google.it/search?q=comune+di+rimini&oq=comune+&aqs=c_1"
VAR259="https://www.google.it/search?q=comune+di+rimini&oq=comune+di&aqs"
VAR260="https://www.google.it/search?q=comune+di+rimini&oq=comune+di+&aq"
VAR261="https://www.google.it/search?q=comune+di+rimini&oq=comune+di+rim"
VAR262="https://www.google.it/search?q=comune+di+rimini&oq=comune+di+rim_1"
VAR263="https://www.google.it/search?q=comune+di+rimini&oq=comune+di+rim_2"
VAR264="https://www.google.it/search?q=comune+di+rimini+facebook&ie=utf-"
VAR265="https://www.google.it/search?q=comune+di+rimini+facebook&oq=comu"
VAR266="https://www.google.it/search?q=comune+di+rimini+facebook&oq=comu_1"
VAR267="https://www.google.it/search?q=comune+di+rimini+facebook&oq=comu_2"
VAR268="https://www.google.it/search?q=comune+di+rimini+fb&oq=comune+di+"
VAR269="https://www.google.it/search?q=comune+di.rimini&oq=comune+di.rim"
VAR270="https://www.google.it/search?q=comune+rimini&oq=c&gs_l=mobile-he"
VAR271="https://www.google.it/search?q=comune+rimini&oq=comune&aqs=chrom"
VAR272="https://www.google.it/search?q=comune+rimini&prmd=mniv&source=ln"
VAR273="https://www.google.it/search?q=comunediRimini&rlz=1Y3XIUG_itIT59"
VAR274="https://www.google.it/search?q=enp+di+rimini+facebook+&oq=enp+di"
VAR275="https://www.google.it/search?q=facebook+comune+di+rimini&oq=face"
VAR276="https://www.google.it/search?q=facebook+comune+di+rimini&oq=face_1"
VAR277="https://www.google.it/search?q=facebook+comune+di+rimini&oq=face_2"
VAR278="https://www.google.it/search?q=facebook+comune+di+rimini&oq=face_3"
VAR279="https://www.google.it/search?q=rimini+comune+facebook&ie=utf-8&o"
VAR280="https://www.google.it/search?redir_esc&client=ms-android-huawei&"
VAR281="https://www.google.it/search?redir_esc&hl=it-IT&oe=utf-8&safe=im"
VAR282="https://www.google.it/search?safe=active&client=ms-android-samsu"
VAR283="https://www.google.it/search?source=hp&ei=6j6VWr-LJobdwQLG5JXwCg"
VAR284="https://www.google.it/search?source=hp&ei=EJ6XWvm8BcfTUcrygIgJ&q"
VAR285="https://www.google.pl/"
VAR286="https://www.google.ru/"
VAR287="https://www.google.sm/"
VAR288="https://www.google.tn/"
VAR289="https://www.messenger.com/"
VAR290="https://www.msn.com/spartan/ntp?locale=it-IT&market=IT&enablereg"
VAR291="https://www.qwant.com/"
;
FORMAT Data DDMMYY10.;
TABLE
Data all, 
VAR3
VAR4
VAR5
VAR6
VAR7
VAR8
VAR9
VAR10
VAR11
VAR12
VAR13
VAR14
VAR15
VAR16
VAR17
VAR18
VAR19
VAR20
VAR21
VAR22
VAR23
VAR24
VAR25
VAR26
VAR27
VAR28
VAR29
VAR30
VAR31
VAR32
VAR33
VAR34
VAR35
VAR36
VAR37
VAR38
VAR39
VAR40
VAR41
VAR42
VAR43
VAR44
VAR45
VAR46
VAR47
VAR48
VAR49
VAR50
VAR51
VAR52
VAR53
VAR54
VAR55
VAR56
VAR57
VAR58
VAR59
VAR60
VAR61
VAR62
VAR63
VAR64
VAR65
VAR66
VAR67
VAR68
VAR69
VAR70
VAR71
VAR72
VAR73
VAR74
VAR75
VAR76
VAR77
VAR78
VAR79
VAR80
VAR81
VAR82
VAR83
VAR84
VAR85
VAR86
VAR87
VAR88
VAR89
VAR90
VAR91
VAR92
VAR93
VAR94
VAR95
VAR96
VAR97
VAR98
VAR99
VAR100
VAR101
VAR102
VAR103
VAR104
VAR105
VAR106
VAR107
VAR108
VAR109
VAR110
VAR111
VAR112
VAR113
VAR114
VAR115
VAR116
VAR117
VAR118
VAR119
VAR120
VAR121
VAR122
VAR123
VAR124
VAR125
VAR126
VAR127
VAR128
VAR129
VAR130
VAR131
VAR132
VAR133
VAR134
VAR135
VAR136
VAR137
VAR138
VAR139
VAR140
VAR141
VAR142
VAR143
VAR144
VAR145
VAR146
VAR147
VAR148
VAR149
VAR150
VAR151
VAR152
VAR153
VAR154
VAR155
VAR156
VAR157
VAR158
VAR159
VAR160
VAR161
VAR162
VAR163
VAR164
VAR165
VAR166
VAR167
VAR168
VAR169
VAR170
VAR171
VAR172
VAR173
VAR174
VAR175
VAR176
VAR177
VAR178
VAR179
VAR180
VAR181
VAR182
VAR183
VAR184
VAR185
VAR186
VAR187
VAR188
VAR189
VAR190
VAR191
VAR192
VAR193
VAR194
VAR195
VAR196
VAR197
VAR198
VAR199
VAR200
VAR201
VAR202
VAR203
VAR204
VAR205
VAR206
VAR207
VAR208
VAR209
VAR210
VAR211
VAR212
VAR213
VAR214
VAR215
VAR216
VAR217
VAR218
VAR219
VAR220
VAR221
VAR222
VAR223
VAR224
VAR225
VAR226
VAR227
VAR228
VAR229
VAR230
VAR231
VAR232
VAR233
VAR234
VAR235
VAR236
VAR237
VAR238
VAR239
VAR240
VAR241
VAR242
VAR243
VAR244
VAR245
VAR246
VAR247
VAR248
VAR249
VAR250
VAR251
VAR252
VAR253
VAR254
VAR255
VAR256
VAR257
VAR258
VAR259
VAR260
VAR261
VAR262
VAR263
VAR264
VAR265
VAR266
VAR267
VAR268
VAR269
VAR270
VAR271
VAR272
VAR273
VAR274
VAR275
VAR276
VAR277
VAR278
VAR279
VAR280
VAR281
VAR282
VAR283
VAR284
VAR285
VAR286
VAR287
VAR288
VAR289
VAR290
VAR291 
/ BOX="38 Daily External Referrers"
;
RUN;

/**************************************************************************/
/* 39 NUMERO DI PERSONE CHE HANNO ESPRESSO COMMENTI NEGATIVI AL GIORNO    */
/**************************************************************************/

TITLE3 "#39 Al giorno: il numero di persone che hanno espresso commenti negativi sulla tua Pagina, per tipo. (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_negative_feedback_39
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Negative Feedback by Type";
RUN;

proc TABULATE DATA=facebook.daily_negative_feedback_39 FORMAT=COMMA10.;
CLASS Data;
VAR 
hide_all_clicks
hide_clicks
report_spam_clicks
unlike_page_clicks
xbutton_clicks
;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
TABLE
Data all, 
hide_all_clicks
hide_clicks
report_spam_clicks
unlike_page_clicks
xbutton_clicks
      / BOX="39 Daily Negative Feedback by Type (UTENTI UNICI)";
RUN;


/********************************************************************************/
/* 42 NUMERO DI VOLTE CHE LE PERSONE HANNO ESPRESSO COMMENTI NEGATIVI AL GIORNO */
/********************************************************************************/
TITLE3 "#42 Al giorno: il numero di volte in cui le persone hanno espresso commenti negativi sulla tua Pagina, per tipo. (Numero totale)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_negative_feedback_42
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Negative Feedback From...";
RUN;

proc TABULATE DATA=facebook.daily_negative_feedback_42 FORMAT=COMMA10.;
CLASS Data;
VAR 
hide_all_clicks
hide_clicks
report_spam_clicks
unlike_page_clicks
xbutton_clicks
;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
TABLE
Data all, 
hide_all_clicks
hide_clicks
report_spam_clicks
unlike_page_clicks
xbutton_clicks
      / BOX="42 Daily Negative Feedback (NUMERO TOTALE)";
RUN;


/***************************************************************************************/
/* 45 GENERE ED ETA DELLE PERSONE CHE SI REGISTRANO USANDO DISPOSITIVI MOBILI AL GIORNO*/
/***************************************************************************************/
TITLE3 "#45 Al giorno: genere ed età delle persone che si registrano nella tua posizione usando dispositivi mobili (Numero totale)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_checkins_bygender_45
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Check-Ins by Gender an...";
RUN;

PROC MEANS DATA=facebook.daily_checkins_bygender_45;
RUN;

/******************************************************************************************/
/* 46 PAESI PRINCIPALI DELLE PERSONE CHE SI REGISTRANO USANDO DISPOSITIVI MOBILI AL GIORNO*/
/******************************************************************************************/
TITLE3 "#46 Al giorno: Paesi principali delle persone che si registrano nel tuo luogo usando dispositivi mobili (Numero totale)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_checkins_bycountry_46
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Check-Ins by Country";
RUN;
PROC MEANS DATA=FACEBOOK.daily_checkins_bycountry_46;
RUN;

/******************************************************************************************/
/* 47 CITTA PRINCIPALI DELLE PERSONE CHE SI REGISTRANO NEL TUO LUOGO                      */
/******************************************************************************************/
TITLE3 "#47 Al giorno: le città principali delle persone che si registrano nel tuo luogo (Numero totale)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_checkins_bycity_47
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Check-ins by City";
RUN;
PROC MEANS DATA=facebook.daily_checkins_bycity_47;
RUN;
/******************************************************************************************/
/* 48 LINGUE PRINCIPALI DELLE PERSONE CHE SI REGISTRANO NEL TUO LUOGO AL GIORNO           */
/******************************************************************************************/

TITLE3 "#48 Al giorno: le lingue principali delle persone che si registrano nel tuo luogo (Numero totale)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_checkins_locale_48
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Check-Ins by Locale";
RUN;
PROC MEANS DATA=facebook.daily_checkins_locale_48;
RUN;

/************************************************************************************************/
/* 49 GENERE ED ETA DELLE PERSONE CHE SI REGISTRANO NELLA TUA POSIZIONE USANDO MOBILE AL GIORNO */
/************************************************************************************************/
TITLE3 "#49 Al giorno: genere ed età delle persone che si registrano nella tua posizione usando dispositivi mobili (Numero totale)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_mobile_bygender_49
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Mobile Check-ins by Ge...";
RUN;
PROC MEANS DATA=facebook.daily_mobile_bygender_49;
RUN;
/***********************************************************************************************/
/* 50 PAESI PRINCIPALI DELLE PERSONE CHE SI REGISTRANO NEL TUO LUOGO USANDO MOBILE AL GIORNO   */
/***********************************************************************************************/

TITLE3 "#51 Al giorno: Paesi principali delle persone che si registrano nel tuo luogo usando dispositivi mobili (Numero totale)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_mobile_checkins_001_50
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Mobile Check-ins by...001";
RUN;
PROC MEANS DATA=facebook.daily_mobile_checkins_001_50;
RUN;
/***********************************************************************************************/
/* 51 CITTA PRINCIPALI DELLE PERSONE CHE SI REGISTRANO NEL TUO LUOGO USANDO MOBILE AL GIORNO   */
/***********************************************************************************************/

TITLE3 "#51 Al giorno: le città principali delle persone che si registrano nel tuo luogo usando dispositivi mobili (numero totale)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_mobile_checkins_002_51
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Mobile Check-ins by...002";
RUN;
PROC MEANS DATA=facebook.daily_mobile_checkins_002_51;
RUN;
/***********************************************************************************************/
/* 52 LINGUE PRINCIPALI DELLE PERSONE CHE SI REGISTRANO NEL TUO LUOGO USANDO MOBILE AL GIORNO  */
/***********************************************************************************************/

TITLE3 "#52 Al giorno: le lingue principali delle persone che si registrano nel tuo luogo usando dispositivi mobili (numero totale)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_mobile_checkins_003_52
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Mobile Check-ins by...003";
RUN;
PROC MEANS DATA=facebook.daily_mobile_checkins_003_52;
RUN;
/**************************************************************************************************************/
/* 53 IL NUMERO DI VOLTE IN CUI LE PERSONE HANNO FORNITO COMMENTI POSITIVI ALLA TUA PAGINA PER TIPO AL GIORNO */
/**************************************************************************************************************/

TITLE3 "#53 Al giorno: il numero di volte in cui le persone hanno fornito commenti positivi alla tua Pagina, per tipo. (Numero totale)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_positive_feedback_53
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Positive Feedback from...";
RUN;

proc TABULATE DATA=facebook.daily_positive_feedback_53 FORMAT=COMMA10.;
CLASS Data;
VAR 
answer
claim
comment
like
link
other
;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
TABLE
Data all, 
answer
claim
comment
like
link
other
      / BOX="53 Daily Positive Feedback (NUMERO TOTALE)";
RUN;


/*******************************************************************************************************************/
/* 56 IL NUMERO DI VOLTE IN CUI LE PERSONE HANNO FORNITO COMMENTI POSITIVI ALLA TUA PAGINA PER TIPO AL GIORNO      */
/*******************************************************************************************************************/
TITLE3 "#56 Al giorno: il numero di volte in cui le persone hanno fornito commenti positivi alla tua Pagina, per tipo. (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_positive_feedback_001_56
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Positive Feedback f...001";
RUN;

proc TABULATE DATA=facebook.daily_positive_feedback_001_56 FORMAT=COMMA10.;
CLASS Data;
VAR 
answer
claim
comment
like
link
other
;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
TABLE
Data all, 
answer
claim
comment
like
link
other
      / BOX="53 Daily Positive Feedback (NUMERO TOTALE)";
RUN;

/***********************************************************************************************/
/* 59 NUMERO DI PERSONE HANNO MESSO MIPIACE ALLA TUA PAGINA QUANDO SONO NEL FUSO ORARIOPST/PDT */
/***********************************************************************************************/

TITLE3 "#59 Al giorno: il numero di persone che hanno messo Mi piace alla tua Pagina e quando sono online nel fuso orario PST/PDT (utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_liked_online_59
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Liked and Online";
RUN;

proc TABULATE DATA=facebook.daily_positive_feedback_001_56 FORMAT=COMMA10.;
CLASS Data;
VAR 
answer
claim
comment
like
link
other
;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
TABLE
Data all, 
answer
claim
comment
like
link
other
      / BOX="53 Daily Positive Feedback (NUMERO TOTALE)";
RUN;


/********************************************************************************************/
/* 60 NUMERO DI CLIC SU INDICAZIONI STRADALI IN TOTALE PER PAGINA IN BASE AL SITO AL GIORNO */
/********************************************************************************************/
TITLE3 "#60 Al giorno: numero di clic su Indicazioni stradali in totale per Pagina in base al sito (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_total_getdirection_60
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Total get direction cl...";
RUN;

proc TABULATE DATA=facebook.daily_total_getdirection_60 FORMAT=COMMA10.;
CLASS Data;
VAR 
API
MOBILE
OTHER
WWW
;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
TABLE
Data all, 
API
MOBILE
OTHER
WWW
      / BOX="60 Daily Total get direction (Utenti unici)";
RUN;


/********************************************************************************************/
/* 62 NUMERO DI CLIC PER EFFETTUARE CHIAMATE IN TOTALE PER PAGINA IN BASE AL SITO AL GIORNO */
/********************************************************************************************/
TITLE3 "#62 Al giorno: numero di clic per effettuare chiamate in totale per Pagina in base al sito (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_total_phonecalls_clic_62
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Total phone calls clic...";
RUN;

proc TABULATE DATA=facebook.daily_total_phonecalls_clic_62 FORMAT=COMMA10.;
CLASS Data;
VAR 
API
MOBILE
OTHER
WWW
;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
TABLE
Data all, 
API
MOBILE
OTHER
WWW
      / BOX="62 Daily Total phone calls (Utenti unici)";
RUN;

/*************************************************************************************/
/* 64 NUMERO DI CLIC SUL SITO WEB IN TOTALE PER PAGINA IN BASE AL SITO AL GIORNO     */
/*************************************************************************************/
TITLE3 "#64 Al giorno: numero di clic sul sito Web in totale per Pagina in base al sito (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_total_website_clic_64
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Total website click co...";
RUN;

PROC MEANS DATA=facebook.daily_total_website_clic_64 maxdec=2;
VAR API	
	MOBILE	
	OTHER
	WWW;
RUN;

proc TABULATE data=facebook.daily_total_website_clic_64 ;
CLASS Data;
VAR API	MOBILE OTHER WWW;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
      TABLE
      Data all, API*f=comma10. MOBILE*f=comma10. OTHER*f=comma10. WWW*f=comma10. / BOX="64 Daily Total website click";
RUN;

DATA TEMP;
mese=month(Data);
SET facebook.daily_total_website_clic_64;
RUN;
proc sort data=TEMP;
by mese;
Run;

PROC FORMAT;
VALUE  MESEFMT
1="Gennaio"
2="Febbraio"
3="Marzo"
4="Aprile"
5="Maggio"
6="Giugno"
7="Luglio"
8="Agosto"
9="Settembre" 
10="Ottobre"
11="Novembre"
12="Dicembre"
;
RUN;

proc TABULATE data=TEMP ;
CLASS mese;
VAR API	MOBILE OTHER WWW;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10. mese MESEFMT.;
      TABLE
      mese all, API*f=comma10. MOBILE*f=comma10. OTHER*f=comma10. WWW*f=comma10. / BOX="64 Daily Total website click";
RUN;


/*********************************************************************************************************/
/* 66 NUMERO TOTALE DI CLIC SUL PUSANTE INDICAZIONI STRADALI PER PAGINA IN BASE A ETA E GENERE PER GIORNO*/
/*********************************************************************************************************/
TITLE3 "#66 Al giorno: numero totale dei clic sul pulsante Indicazioni stradali per Pagina in base a età e genere (Utenti unici)";

PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_total_getdirection_001_66
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Total get direction...001";
RUN;

proc TABULATE data=facebook.daily_total_getdirection_001_66 format=comma10. ;
CLASS Data;
VAR 
_13_17_F
_13_17_M
_13_17_U
_18_24_F
_18_24_M
_18_24_U
_25_34_F
_25_34_M
_25_34_U
_35_44_F
_35_44_M
_35_44_U
_45_54_F
_45_54_M
_45_54_U
_55_64_F
_55_64_M
_55_64_U
_65__F
_65__M
_65__U
_13_F
_13_M
_13_U
UNKNOWN_F
UNKNOWN_M
UNKNOWN_U;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL _13_F="F <13" F_13_17="F 13-17" F_18_24="F 18-24" F_25_34="F 25-34" F_35_44="F 35-44" F_45_54="F 45-54" F_55_64="F 55-64" F_65_="F 65>"
      _13_M="M <13" M_13_17="M 13-17" M_18_24="M 18-24" M_25_34="M 25-34" M_35_44="M 35-44" M_45_54="M 45-54" M_55_64="M 55-64" M_65_="M 65+"
      _13_U="U <13" U_13_17="U 13-17" U_18_24="U 18-24" U_25_34="U 25-34" U_35_44="U 35-44" U_45_54="U 45-54" U_55_64="U 55-64" U_65_="U 65+"
      UNKNOWN_F="F senza età"
      UNKNOWN_M="M senza età"
      UNKNOWN_U="U senza età"; 
      TABLE
      Data all, 
_13_F
_13_17_F
_18_24_F
_25_34_F
_35_44_F
_45_54_F
_55_64_F
_65__F
_13_U
_13_17_M
_18_24_M
_25_34_M
_35_44_M
_45_54_M
_55_64_M
_65__M
_13_17_U
_18_24_U
_25_34_U
_35_44_U
_45_54_U
_55_64_U
_65__U
UNKNOWN_F
UNKNOWN_M
UNKNOWN_U
      / BOX="66 Daily Total get direction by gender and age (Utenti Unici)";
RUN;


/*************************************************************************************************************/
/* 68 NUMERO TOTALE DI CLIC PER EFFETTUARE CHIAMATE PER PAGINA IN BASE A ETA E GENERE AL GIORNO              */
/*************************************************************************************************************/

TITLE3 "#68 Al giorno: numero totale di clic per effettuare chiamate per Pagina in base a età e genere (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_total_phone_calls_001_68
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Total phone calls c...001";
RUN;

proc TABULATE data=facebook.daily_total_phone_calls_001_68 format=comma10. ;
CLASS Data;
VAR 
_13_17_F
_13_17_M
_13_17_U
_18_24_F
_18_24_M
_18_24_U
_25_34_F
_25_34_M
_25_34_U
_35_44_F
_35_44_M
_35_44_U
_45_54_F
_45_54_M
_45_54_U
_55_64_F
_55_64_M
_55_64_U
_65__F
_65__M
_65__U
_13_F
_13_M
_13_U
UNKNOWN_F
UNKNOWN_M
UNKNOWN_U;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL _13_F="F <13" _13_17_F="F 13-17" _18_24_F="F 18-24" _25_34_F="F 25-34" _35_44_F="F 35-44" _45_54_F="F 45-54" _55_64_F="F 55-64" _65__F="F 65>"
      _13_M="M <13" _13_17_M="M 13-17" _18_24_M="M 18-24" _25_34_M="M 25-34" _35_44_M="M 35-44" _45_54_M="M 45-54" _55_64_M="M 55-64" _65__M="M 65+"
      _13_U="U <13" _13_17_U="U 13-17" _18_24_U="U 18-24" _25_34_U="U 25-34" _35_44_U="U 35-44" _45_54_U="U 45-54" _55_64_U="U 55-64" _65__U="U 65+"
      UNKNOWN_F="F senza età"
      UNKNOWN_M="M senza età"
      UNKNOWN_U="U senza età"; 
      TABLE
      Data all, 
_13_F
_13_17_F
_18_24_F
_25_34_F
_35_44_F
_45_54_F
_55_64_F
_65__F
_13_U
_13_17_M
_18_24_M
_25_34_M
_35_44_M
_45_54_M
_55_64_M
_65__M
_13_17_U
_18_24_U
_25_34_U
_35_44_U
_45_54_U
_55_64_U
_65__U
UNKNOWN_F
UNKNOWN_M
UNKNOWN_U
      / BOX="68 Daily Total phone calls by gender and age (Utenti Unici)";
RUN;



/*********************************************************************************************/
/* 70 NUMERO TOTALE DI CLIC SUL SITO WEB PER PAGINA IN BASE A ETA E GENERE AL GIORNO         */
/*********************************************************************************************/
TITLE3 "#70 Al giorno: numero totale dei clic sul sito Web per Pagina in base a età e genere (Utenti unici)";
PROC IMPORT DATAFILE="&page"
		    OUT=facebook.daily_total_website_click_70
		    DBMS=XLSX
		    REPLACE;
SHEET="Daily Total web site click c...";
RUN;

proc TABULATE data=facebook.daily_total_website_click_70 format=comma10. ;
CLASS Data;
VAR 
_13_17_F
_13_17_M
_13_17_U
_18_24_F
_18_24_M
_18_24_U
_25_34_F
_25_34_M
_25_34_U
_35_44_F
_35_44_M
_35_44_U
_45_54_F
_45_54_M
_45_54_U
_55_64_F
_55_64_M
_55_64_U
_65__F
_65__M
_65__U
_13_F
_13_M
_13_U
UNKNOWN_F
UNKNOWN_M
UNKNOWN_U;
KEYLABEL all="TOTALE";
KEYLABEL n="N";
FORMAT Data DDMMYY10.;
LABEL _13_F="F <13" _13_17_F="F 13-17" _18_24_F="F 18-24" _25_34_F="F 25-34" _35_44_F="F 35-44" _45_54_F="F 45-54" _55_64_F="F 55-64" _65__F="F 65>"
      _13_M="M <13" _13_17_M="M 13-17" _18_24_M="M 18-24" _25_34_M="M 25-34" _35_44_M="M 35-44" _45_54_M="M 45-54" _55_64_M="M 55-64" _65__M="M 65+"
      _13_U="U <13" _13_17_U="U 13-17" _18_24_U="U 18-24" _25_34_U="U 25-34" _35_44_U="U 35-44" _45_54_U="U 45-54" _55_64_U="U 55-64" _65__U="U 65+"
      UNKNOWN_F="F senza età"
      UNKNOWN_M="M senza età"
      UNKNOWN_U="U senza età"; 
      TABLE
      Data all, 
_13_F
_13_17_F
_18_24_F
_25_34_F
_35_44_F
_45_54_F
_55_64_F
_65__F
_13_U
_13_17_M
_18_24_M
_25_34_M
_35_44_M
_45_54_M
_55_64_M
_65__M
_13_17_U
_18_24_U
_25_34_U
_35_44_U
_45_54_U
_55_64_U
_65__U
UNKNOWN_F
UNKNOWN_M
UNKNOWN_U
      / BOX="70 Daily click website by gender and age (Utenti Unici)";
RUN;