/**************************************************************/
/** Gestisce statistiche trimestrali su Facebook POSTA DATA  **/
/** Author: @mauroferri Data: 22/2/2018 .                    **/
/**************************************************************/

LIBNAME facebook "/folders/myfolders/sasuser.v94/facebook";
%let trimestre=Gennaio 2018;
%let file=/folders/myfolders/sasuser.v94/facebook/Facebook Insights Data Export (Post Level) - Comune di Rimini - GEN2018.xlsx;

RUN;

PROC IMPORT DATAFILE="&file"
            OUT=facebook.key_metrics
		    DBMS=XLSX
		    REPLACE;
		    DATAROW=3;
SHEET="Key Metrics";
RUN;

PROC IMPORT DATAFILE="&file"
		    OUT=facebook.lifetime_talking
		    DBMS=XLSX
		    REPLACE;
SHEET="Lifetime Talking About This(...";
RUN;

PROC IMPORT DATAFILE="&file"
		    OUT=facebook.post_stories
		    DBMS=XLSX
		    REPLACE;
SHEET="Lifetime Post Stories by act...";
RUN;

PROC IMPORT DATAFILE="&file"
		    OUT=facebook.post_consumers
		    DBMS=XLSX
		    REPLACE;
SHEET="Lifetime Post Consumers by type";
RUN;

PROC IMPORT DATAFILE="&file"
		    OUT=facebook.post_consumptions
		    DBMS=XLSX
		    REPLACE;
SHEET="Lifetime Post Consumptions b...";
RUN;


PROC IMPORT DATAFILE="&file"
		    OUT=facebook.negative_feedback_0
		    DBMS=XLSX
		    REPLACE;
SHEET="Lifetime Negative Feedback f...";
RUN;

PROC IMPORT DATAFILE="&file"
		    OUT=facebook.negative_feedback_1
		    DBMS=XLSX
		    REPLACE;
SHEET="Lifetime Negative Feedback";
RUN;


/* Formati delle Variabili */

PROC FORMAT lib=facebook;
VALUE PORTATAF      0-1000='0-5.000'
                 5001-10000='5.001-10.000'
                10001-20000='10.001-20.000'
                20001-30000='20.001-30.000'
                30001-40000='30.001-40.000'
                40001-60000='40.001-60.000'
                60001-80000='60.001-80.000'
                80001-100000='80.001-100.000'
               100001-120000='100.000-120.000'
               120001-140000='120.001-140.000'
               140001-HIGH='OLTRE 140.000'
;

VALUE LIKEF 0-10="Da 0 a 10"
            11-20="Da 11 a 20"
            21-30="Da 21 a 30"
            31-40="Da 31 a 40"
            41-50="Da 41 a 50"
            51-HIGH="Oltre 50"
;

VALUE COMMENTF 0-10="Da 0 a 10"
            11-20="Da 11 a 20"
            21-30="Da 21 a 30"
            31-40="Da 31 a 40"
            41-50="Da 41 a 50"
            51-HIGH="Oltre 50"
;

VALUE SHAREF 0-10="Da 0 a 10"
            11-20="Da 11 a 20"
            21-30="Da 21 a 30"
            31-40="Da 31 a 40"
            41-50="Da 41 a 50"
            51-HIGH="Oltre 50"
;
RUN;


/** Print the results. RISULTATI DI MASSIMA **/
/*
PROC FREQ DATA=facebook.key_metrics;
     TABLES Copertura_totale_del_post_nella*Elemento_pubblicato;
     FORMAT Copertura_totale_del_post_nella FPORTATA.;
     TITLE "Copertura totale del post nella sua durata";
RUN;
PROC freq DATA=facebook.lifetime_talking;
     TABLEs like*tipo;
RUN;
PROC MEANS DATA=facebook.key_metrics;
Run;
PROC MEANS DATA=facebook.lifetime_talking;
RUN;
PROC PRINT DATA=facebook.key_metrics;
PROC PRINT DATA=facebook.lifetime_talking;
RUN;
*/

TITLE1 'COMUNE DI RIMINI - UFFICIO COMUNICAZIONE';
TITLE2 "Facebook Insights POST Level &trimestre";
FOOTNOTE2 'Elaborazione della Redazione web';

OPTIONS linesize=116 PAGESIZE=62 NONUMBER NODATE CENTER;

proc sort data=facebook.key_metrics out=temp;
   by descending Copertura_totale_del_post_nella;
run;
title3 "1 Elenco post Facebook in ordine di Copertura >10000";
proc report data=temp nowindows headline headskip
            ls=100 ps=45;
   where Copertura_totale_del_post_nella between 10000 and 200000;
   column Tipo Messaggio_post Copertura_totale_del_post_nella Impression_totali_del_post_nella Utenti_coinvolti_in_totale;

   define  Tipo    /  format=$20.'Tipo';

   define  Messaggio_post / format=$80. width=100 'Messaggio';
   define  price   / format=dollar10. width=10 'Price';
   define  Copertura_totale_del_post_nella  / format=COMMA12. width=15 'Copertura';
   define  Impression_totali_del_post_nella / format=COMMA12. width=15 'Visualizzazioni';
   define  Utenti_coinvolti_in_totale  / format=comma12. width=15  'Utenti coinvolti';
   
 /*  break after Tipo / skip; */

 /*  
     title4 'Intervallo di copertura tra 10mila e 200mila per Tipo di Post';
     footnote "Elenco pubblicato il &sysdate"; */
run;

/* Tabella Media portata e visualizzazioni per tipo */
title3 "2 Media Copertura e Visualizzazioni per Tipo";
proc TABULATE data=facebook.key_metrics; 
CLASS tipo;
VAR Copertura_totale_del_post_nella Impression_totali_del_post_nella;
KEYLABEL all='TOTALE';
KEYLABEL n='N' mean="Media" min="Minimo" max="Massimo";
LABEL tipo="Tipo" Copertura_totale_del_post_nella="Copertura" Impression_totali_del_post_nella="Visualizzazioni"; 
      TABLE
        tipo all , Copertura_totale_del_post_nella*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.) Impression_totali_del_post_nella*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.) / RTS=50 MISSTEXT='-'
          BOX="2";
RUN;

/* Statistica di tutte le key metrics    */ 
/* Tabella con tutte le metriche di base */
title3 "3 Media di tutte le key metrics PER TIPO";
proc TABULATE data=facebook.key_metrics format=comma10.; 
CLASS tipo;
VAR 
Copertura_totale_del_post_nella
Copertura_organica_del_post_in_t
Copertura_del_post_a_pagamento_i
Impression_totali_del_post_nella
Impression_organiche_dei_post_in
Impression_del_post_a_pagamento
Utenti_coinvolti_in_totale
Utilizzatori_del_post_in__totale
Utilizzi_del_post_in_totale
Commenti_negativi_in_totale
Commenti_negativi_dagli_utenti_i
Impression_del_post_in_totale_in
Copertura_totale_del_post_da_par
Impression_del_post_a_pagamento1
Copertura_del_post_in_totale_da
Il_numero_di_persone_in_totale_a
Visualizzazioni_organiche_fino_a
Visualizzazioni_organiche_fino_1
Visualizzazioni_a_pagamento_fino
Visualizzazioni_a_pagamento_fin1
Visualizzazioni_del_video_organi
Visualizzazioni_del_video_organ1
Visualizzazioni_del_video_a_paga
Visualizzazioni_del_video_a_pag1
Durata_media_di_visualizzazione
Durata_del_video_in_totale
;
KEYLABEL all='TOTALE';
KEYLABEL n='N' mean="Media" min="Minimo" max="Massimo";
LABEL 	
Copertura_totale_del_post_nella="Copertura totale del post nella sua durata"
Copertura_organica_del_post_in_t="Copertura organica del post in totale"
Copertura_del_post_a_pagamento_i="Copertura del post a pagamento in totale"
Impression_totali_del_post_nella="Impression totali del post nella sua durata"
Impression_organiche_dei_post_in="Impression organiche dei post in totale"
Impression_del_post_a_pagamento="Impression del post a pagamento in totale"
Utenti_coinvolti_in_totale="Utenti coinvolti in totale"
Utilizzatori_del_post_in__totale="Utilizzatori del post in totale"
Utilizzi_del_post_in_totale="Utilizzi del post in totale"
Commenti_negativi_in_totale="Commenti negativi in totale"
Commenti_negativi_dagli_utenti_i="Commenti negativi dagli utenti in totale"
Impression_del_post_in_totale_in="Impression del post in totale in base alle persone a cui piace l"
Copertura_totale_del_post_da_par="Copertura totale del post da parte delle persone a cui piace la"
Impression_del_post_a_pagamento1="Impression del post a pagamento in totale in base alle persone a"
Copertura_del_post_in_totale_da="Copertura del post in totale da parte delle persone a cui piace"
Il_numero_di_persone_in_totale_a="Il numero di persone in totale a cui piace la tua Pagina e che h"
Visualizzazioni_organiche_fino_a="Visualizzazioni organiche fino al 95% in totale"
Visualizzazioni_organiche_fino_1="Visualizzazioni organiche fino al 95% in totale_1"
Visualizzazioni_a_pagamento_fino="Visualizzazioni a pagamento fino al 95% in totale"
Visualizzazioni_a_pagamento_fin1="Visualizzazioni a pagamento fino al 95% in totale_1"
Visualizzazioni_del_video_organi="Visualizzazioni del video organiche in totale"
Visualizzazioni_del_video_organ1="Visualizzazioni del video organiche in totale_1"
Visualizzazioni_del_video_a_paga="Visualizzazioni del video a pagamento in totale"
Visualizzazioni_del_video_a_pag1="Visualizzazioni del video a pagamento in totale_1"
Durata_media_di_visualizzazione="Durata media di visualizzazione del video in totale"
Durata_del_video_in_totale="Durata del video in totale"
;
TABLE tipo all,
Copertura_totale_del_post_nella*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Copertura_organica_del_post_in_t*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Copertura_del_post_a_pagamento_i*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Impression_totali_del_post_nella*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Impression_organiche_dei_post_in*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Impression_del_post_a_pagamento*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Utenti_coinvolti_in_totale*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Utilizzatori_del_post_in__totale*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Utilizzi_del_post_in_totale*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Commenti_negativi_in_totale*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Commenti_negativi_dagli_utenti_i*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Impression_del_post_in_totale_in*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Copertura_totale_del_post_da_par*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Impression_del_post_a_pagamento1*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Copertura_del_post_in_totale_da*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Il_numero_di_persone_in_totale_a*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Visualizzazioni_organiche_fino_a*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Visualizzazioni_organiche_fino_1*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Visualizzazioni_a_pagamento_fino*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Visualizzazioni_a_pagamento_fin1*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Visualizzazioni_del_video_organi*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Visualizzazioni_del_video_organ1*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Visualizzazioni_del_video_a_paga*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Visualizzazioni_del_video_a_pag1*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Durata_media_di_visualizzazione*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
Durata_del_video_in_totale*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)
/ RTS=50 MISSTEXT='-' BOX="3";
RUN;

/* Tabella Media, Minimo e Massimo di persone che seguono la pagina che hanno interagito con il post */
TITLE3 "4 Media persone che seguono la pagina che hanno interagito con il post per Tipo";
proc TABULATE data=facebook.key_metrics; 
CLASS tipo;
VAR Il_numero_di_persone_in_totale_a;
KEYLABEL all='TOTALE';
KEYLABEL n='N' mean="Media" min="Minimo" max="Massimo";
LABEL tipo="Tipo" Il_numero_di_persone_in_totale_a="Fan che hanno interagito"; 
      TABLE
        tipo all , Il_numero_di_persone_in_totale_a*(mean*f=COMMA12.2 min*f=COMMA12. max*f=COMMA12.)  / RTS=50 MISSTEXT='-'
          BOX="4";
RUN;

/* Tabella Totale Like Share e Commenti per tipo */
TITLE3 "5 Numero di persone che hanno creato una notizia sul post della tua Pagina interagendovi. (Utenti unici)";
proc TABULATE data=facebook.lifetime_talking; 
CLASS tipo;
VAR like share comment;
KEYLABEL all='TOTALE';
KEYLABEL pctn='% riga';
KEYLABEL pctsum='% colonna';
KEYLABEL n='N' sum="Somma";
LABEL tipo="Tipo" like="Like" share="Condivisioni" comment="Commenti"; 
      TABLE
        tipo all , like*(sum*f=COMMA12. pctsum*f=COMMA12.2) share*(sum*f=COMMA12. pctsum*f=COMMA12.2) comment*(sum*f=COMMA12. pctsum*f=COMMA12.2) all*(n*f=COMMA12. pctn<tipo all>*f=COMMA12.2)/ RTS=50 MISSTEXT='-'
          BOX="5";
RUN;

/* Tabella Consumers */
TITLE3 "6 Numero di persone che hanno cliccato ovunque sul tuo post, per tipo. (Utenti unici)";
proc TABULATE data=facebook.post_consumers; 
CLASS tipo;
VAR photo_view other_clicks link_clicks video_play;
KEYLABEL all='TOTALE';
KEYLABEL pctn='% riga';
KEYLABEL pctsum='% colonna';
KEYLABEL n='N' sum="Somma";
LABEL tipo="Tipo" photo_view="Visualizzazioni di foto" other_clicks="Altri click" link_clicks="Click sul link" video_play="Video Play"; 
      TABLE
        tipo all , photo_view*(sum*f=COMMA12. pctsum*f=COMMA12.2) other_clicks*(sum*f=COMMA12. pctsum*f=COMMA12.2) link_clicks*(sum*f=COMMA12. pctsum*f=COMMA12.2) video_play*(sum*f=COMMA12. pctsum*f=COMMA12.2) all*(n*f=COMMA12. pctn<tipo all>*f=COMMA12.2)/ RTS=50 MISSTEXT='-'
          BOX="6";
RUN;

/* Tabella consuption */
TITLE3 "7 Numero di clic ovunque sul tuo post, per tipo. (Numero totale)";
proc TABULATE data=facebook.post_consumptions; /* Tabella Consumptions */
CLASS tipo;
VAR photo_view other_clicks link_clicks video_play;
KEYLABEL all='TOTALE';
KEYLABEL pctn='% riga';
KEYLABEL pctsum='% colonna';
KEYLABEL n='N' sum="Somma";
LABEL tipo="Tipo" photo_view="Visualizzazioni di foto" other_clicks="Altri click" link_clicks="Click sul link" video_play="Video Play"; 
      TABLE
        tipo all , photo_view*(sum*f=COMMA12. pctsum*f=COMMA12.2) other_clicks*(sum*f=COMMA12. pctsum*f=COMMA12.2) link_clicks*(sum*f=COMMA12. pctsum*f=COMMA12.2) video_play*(sum*f=COMMA12. pctsum*f=COMMA12.2) all*(n*f=COMMA12. pctn<tipo all>*f=COMMA12.2)/ RTS=50 MISSTEXT='-'
          BOX="7";
RUN;

/* Tabella post stories */
TITLE3 "8 Il numero di notizie create sul post della tua Pagina, per tipo di azione. (Numero totale)";
proc TABULATE data=facebook.post_stories;  
CLASS tipo;
VAR like share comment;
KEYLABEL all='TOTALE';
KEYLABEL pctn='% riga';
KEYLABEL pctsum='% colonna';
KEYLABEL n='N' sum="Somma";
LABEL tipo="Tipo" like="Like" share="Condivisioni" comment="Commenti"; 
      TABLE
        tipo all , like*(sum*f=COMMA12. pctsum*f=COMMA12.2) share*(sum*f=COMMA12. pctsum*f=COMMA12.2) comment*(sum*f=COMMA12. pctsum*f=COMMA12.2) all*(n*f=COMMA12. pctn<tipo all>*f=COMMA12.2)/ RTS=50 MISSTEXT='-'
          BOX="8";
RUN;

/* Tabella negative feedback (Totale) */
TITLE3 "9 Totale: il numero di volte in cui le persone hanno fornito commenti negativi al tuo post, per tipo. (Numero totale)";
proc TABULATE data=facebook.negative_feedback_0;  
CLASS tipo;
VAR hide_clicks hide_all_clicks;
KEYLABEL all='TOTALE';
KEYLABEL pctn='% riga';
KEYLABEL pctsum='% colonna';
KEYLABEL n='N' sum="Somma";
LABEL tipo="Tipo" hide_clicks="Hide Clicks" hide_all_clicks="Hide All Clicks"; 
      TABLE
        tipo all , hide_clicks*(sum*f=COMMA12. pctsum*f=COMMA12.2) hide_all_clicks*(sum*f=COMMA12. pctsum*f=COMMA12.2) all*(n*f=COMMA12. pctn<tipo all>*f=COMMA12.2)
        / RTS=50 MISSTEXT='-' BOX="9";
RUN;

/* Tabella negative feedback (Utenti) */
TITLE3 "10 Totale: il numero di persone che hanno fornito commenti negativi sul tuo post, per tipo. (Utenti unici)";

proc TABULATE data=facebook.negative_feedback_1;  
CLASS tipo;
VAR hide_clicks hide_all_clicks;
KEYLABEL all='TOTALE';
KEYLABEL pctn='% riga';
KEYLABEL pctsum='% colonna';
KEYLABEL n='N' sum="Somma";
LABEL tipo="Tipo" hide_clicks="Hide Clicks" hide_all_clicks="Hide All Clicks"; 
      TABLE
        tipo all , hide_clicks*(sum*f=COMMA12. pctsum*f=COMMA12.2) hide_all_clicks*(sum*f=COMMA12. pctsum*f=COMMA12.2) all*(n*f=COMMA12. pctn<tipo all>*f=COMMA12.2)
        / RTS=50 MISSTEXT='-' BOX="10";
RUN;

